# Y LIFT Javascript Client

[![Version][npm-version-badge]][npm-version-link]
[![Build Status][build-status-badge]][build-status-link]
[![Downloads][downloads-badge]][downloads-link]
[![Try on RunKit][runkit-badge]][runkit-link]

A JavaScript interface to the [Y LIFT API][ylift-docs-link]. To get started
install via npm:

```bash
npm install --save ylift
```

## Getting Started

First, you'll need to register a client application. This can currently only be
done by [reaching out to the engineering team](mailto:engineering@ghostcreative.io).

### Single Page Apps

```js
const ylift = require('ylift');

const client = ylift.create({
  clientId: 'CLIENT_ID',
  redirectUri: 'http://www.example.com/oauth/callbacks/ylift'
});

// Send the user to the authorization URL, where they can choose to grant your
// app permissions to access the service on their behalf (if permission has
// already been given, they'll automatically be redirected)
window.location = client.getAuthorizeUri('token');

// token will be returned as the query param `authToken` to your redirect URL
const querystring = require('query-string');
const parsed = querystring.parse(location.hash);
client.setAccessToken(parsed.access_token);
```

NOTE: The process of token retrieval will need to be performed again when the
token becomes invalid (they're currently valid for 24 hours).

### Server Applications

Because servers can be trusted to keep a secret, setup is much more
straightforward.

Client Authentication:

```js
const ylift = require('ylift');

const client = ylift.create({
  clientId: 'CLIENT_ID',
  clientSecret: 'CLIENT_SECRET'
});
```

Acting on behalf of a user:

```js
const redirectUrl = client.getAuthorizeUri('code');

// Send the user to the authorization URL, where they can choose to grant your
// app permissions to access the service on their behalf (if permission has
// already been given, they'll automatically be redirected)

// the code to exchange will be returned as the query param `code` to your
// redirect URL
const querystring = require('query-string');
const parsed = querystring.parse(location.search);
client.setAuthorizationCode(parsed.code);
```

### Parameters

| Parameter | Usage | Example |
|-----------|-------|---------|
| `clientId`*    | Registered Client ID | `'46ef9d9b-89a9-4fd2-84cf-af6de31f2618'` |
| `clientSecret` | Registered Client Secret | `'59170c3e-e2c9-4244-92d8-c3595d4af325'` |
| `baseApiUrl`   | Specify an alternate server to request resources from | `'https://stage.api.ylift.com/v1'` |
| `baseAuthUrl`  | Specify an alternate server to request auth tokens from | `'https://stage.accounts.ylift.com'` |
| `redirectUri`  | Path to redirect auth requests to (required for `#get_authorize_uri`) | `'https://app.example.com/oauth/callbacks/ylift'` |
| `request`      | [`axios`][axios-project-link] is used under the hood, pass a config through here | |

## Basic Usage

```js
client.products.get('SOME_PRODUCT_ID')
  .then(product => console.log(product))
  .catch(err => console.log('Got an error!', err));
```

## Resources

### Notes

* `*` and bolded `Type` indicates required param
* All list resources have a max of 50 elements per request (e.g. `limit`s higher than that will have no effect)

| Entity | Method Base |
|--------|-------------|
TODO

[npm-version-badge]: https://img.shields.io/npm/v/ylift-js.svg
[npm-version-link]: https://www.npmjs.org/package/ylift-js
[build-status-badge]: https://travis-ci.org/ghostcreative/ylift-js.svg?branch=master
[build-status-link]: https://travis-ci.org/ghostcreative/ylift-js
[downloads-badge]: https://img.shields.io/npm/dm/ylift.svg
[downloads-link]: https://www.npmjs.com/package/ylift
[runkit-badge]: https://badge.runkitcdn.com/ylift.svg
[runkit-link]: https://runkit.com/npm/ylift-js

[axios-project-link]: https://github.com/mzabriskie/axios#request-config
[ylift-docs-link]: https://docs.hud.ai
[project-config-link]: https://github.com/ghostcreative/ylift-js/blob/master/lib/util/ClientConfigFactory.ts#L16
