"use strict";
exports.__esModule = true;
var _ = require("lodash");
var Promise = require("bluebird");
var isAfter = require("date-fns/is_after");
var addMilliseconds = require("date-fns/add_milliseconds");
var ClientConfigFactory_1 = require("./utils/ClientConfigFactory");
var RequestManager_1 = require("./RequestManager");
var ClientError_1 = require("./utils/ClientError");
var resources_1 = require("./resources");
var Client = (function () {
    function Client(config) {
        this.baseApiUrl = config.baseApiUrl || 'https://api.ylift.com/v1';
        this.baseAuthUrl = config.baseAuthUrl || 'https://accounts.ylift.com';
        if (config.redirectUri)
            this.redirectUri = config.redirectUri;
        this.clientId = config.clientId;
        if (config.clientSecret)
            this.clientSecret = config.clientSecret;
        this.requestManager = new RequestManager_1.RequestManager(this, config);
        this.accountPlan = new resources_1.AccountPlanResource(this.requestManager);
        this.accountSubscription = new resources_1.AccountSubscriptionResource(this.requestManager);
        this.address = new resources_1.AddressResource(this.requestManager);
        this.banner = new resources_1.BannerResource(this.requestManager);
        this.cart = new resources_1.CartResource(this.requestManager);
        this.cartItem = new resources_1.CartItemResource(this.requestManager);
        this.clinic = new resources_1.ClinicResource(this.requestManager);
        this.event = new resources_1.EventResource(this.requestManager);
        this.license = new resources_1.LicenseResource(this.requestManager);
        this.networkFile = new resources_1.NetworkFileResource(this.requestManager);
        this.order = new resources_1.OrderResource(this.requestManager);
        this.orderAddress = new resources_1.OrderAddressResource(this.requestManager);
        this.orderItem = new resources_1.OrderItemResource(this.requestManager);
        this.patient = new resources_1.PatientResource(this.requestManager);
        this.patientAddress = new resources_1.PatientAddressResource(this.requestManager);
        this.patientAllergy = new resources_1.PatientAllergyResource(this.requestManager);
        this.plan = new resources_1.PlanResource(this.requestManager);
        this.prescription = new resources_1.PrescriptionResource(this.requestManager);
        this.prescriptionCart = new resources_1.PrescriptionCartResource(this.requestManager);
        this.prescriptionCartItem = new resources_1.PrescriptionCartItemResource(this.requestManager);
        this.pricingRule = new resources_1.PricingRuleResource(this.requestManager);
        this.product = new resources_1.ProductResource(this.requestManager);
        this.productAttribute = new resources_1.ProductAttributeResource(this.requestManager);
        this.productBrand = new resources_1.ProductBrandResource(this.requestManager);
        this.productBrandMedia = new resources_1.ProductBrandMediaResource(this.requestManager);
        this.productBundle = new resources_1.ProductBundleResource(this.requestManager);
        this.productBundleItem = new resources_1.ProductBundleItemResource(this.requestManager);
        this.productCategory = new resources_1.ProductCategoryResource(this.requestManager);
        this.productClick = new resources_1.ProductClickResource(this.requestManager);
        this.productMedia = new resources_1.ProductMediaResource(this.requestManager);
        this.productShippingSetting = new resources_1.ProductShippingSettingResource(this.requestManager);
        this.productSubcategory = new resources_1.ProductSubcategoryResource(this.requestManager);
        this.profile = new resources_1.ProfileResource(this.requestManager);
        this.profileEmail = new resources_1.ProfileEmailResource(this.requestManager);
        this.profileLicense = new resources_1.ProfileLicenseResource(this.requestManager);
        this.profileVendorContact = new resources_1.ProfileVendorContactResource(this.requestManager);
        this.promoCode = new resources_1.PromoCodeResource(this.requestManager);
        this.resaleCertificate = new resources_1.ResaleCertificateResource(this.requestManager);
        this.review = new resources_1.ReviewResource(this.requestManager);
        this.role = new resources_1.RoleResource(this.requestManager);
        this.salesAccount = new resources_1.SalesAccountResource(this.requestManager);
        this.salesAccountAddress = new resources_1.SalesAccountAddressResource(this.requestManager);
        this.salesAccountContact = new resources_1.SalesAccountContactResource(this.requestManager);
        this.shipping = new resources_1.ShippingResource(this.requestManager);
        this.sku = new resources_1.SkuResource(this.requestManager);
        this.skuProductAttributeDescription = new resources_1.SkuProductAttributeDescriptionResource(this.requestManager);
        this.stateTaxableProductCategoryExemptionRule = new resources_1.StateTaxableProductCategoryExemptionRuleResource(this.requestManager);
        this.subscription = new resources_1.SubscriptionResource(this.requestManager);
        this.taxableProductCategory = new resources_1.TaxableProductCategoryResource(this.requestManager);
        this.taxExemptionRule = new resources_1.TaxExemptionRuleResource(this.requestManager);
        this.training = new resources_1.TrainingResource(this.requestManager);
        this.trainingCategory = new resources_1.TrainingCategoryResource(this.requestManager);
        this.trainingCompletion = new resources_1.TrainingCompletionResource(this.requestManager);
        this.trainingLocation = new resources_1.TrainingLocationResource(this.requestManager);
        this.trainingLecture = new resources_1.TrainingLectureResource(this.requestManager);
        this.trainingStatistics = new resources_1.TrainingStatisticsResource(this.requestManager);
        this.trainingMaterial = new resources_1.TrainingMaterialResource(this.requestManager);
        this.trainingModule = new resources_1.TrainingModuleResource(this.requestManager);
        this.trainingQuestion = new resources_1.TrainingQuestionResource(this.requestManager);
        this.trainingAnswer = new resources_1.TrainingAnswerResource(this.requestManager);
        this.trainingQuiz = new resources_1.TrainingQuizResource(this.requestManager);
        this.vendor = new resources_1.VendorResource(this.requestManager);
        this.vendorAddress = new resources_1.VendorAddressResource(this.requestManager);
        this.vendorContact = new resources_1.VendorContactResource(this.requestManager);
        this.vendorOrderRule = new resources_1.VendorOrderRuleResource(this.requestManager);
        this.vendorShippingSetting = new resources_1.VendorShippingSettingResource(this.requestManager);
        this.trainingRatings = new resources_1.TrainingRatingsResource(this.requestManager);
        this.trainingDiscounts = new resources_1.TrainingDiscountsResource(this.requestManager);
        this.environmentSettings = new resources_1.EnvironmentSettingsResource(this.requestManager);
        this.productDiscount = new resources_1.ProductDiscountResource(this.requestManager);
        this.productDiscountThreshold = new resources_1.ProductDiscountThresholdResource(this.requestManager);
        this.combinedDiscount = new resources_1.CombinedDiscountResource(this.requestManager);
        this.combinedDiscountItem = new resources_1.CombinedDiscountItemResource(this.requestManager);
    }
    Client.create = function (clientConfig) {
        var config = ClientConfigFactory_1.Factory(clientConfig);
        return new Client(config);
    };
    Client.prototype.getAuthorizeUri = function (responseType) {
        if (responseType === void 0) { responseType = 'code'; }
        if (!this.redirectUri)
            throw new ClientError_1.ClientError('cannot generate authorization URL without redirectUri');
        var params = _.map({
            response_type: responseType,
            client_id: this.clientId,
            redirect_uri: this.redirectUri
        }, function (value, key) { return key + "=" + encodeURIComponent(value); }).join('&');
        return this.baseAuthUrl + "/oauth2/authorize?" + params;
    };
    Client.prototype.getLogoutUri = function () {
        if (!this.redirectUri)
            throw new ClientError_1.ClientError('cannot generate logout URL without redirectUri');
        return this.baseAuthUrl + "/logout/?redirectTo=" + this.redirectUri;
    };
    Client.prototype.refreshTokens = function () {
        if (this.tokenExpiresAt && isAfter(this.tokenExpiresAt, new Date()))
            return Promise.resolve();
        if (this.authorizationCode)
            return this.exchangeAuthCode();
        if (this.refreshToken)
            return this.handleTokenRefresh();
        if (this.clientSecret)
            return this.exchangeClientCredentials();
        return Promise.resolve();
    };
    Client.prototype.setAccessToken = function (accessToken) {
        this.accessToken = accessToken;
    };
    Client.prototype.setAuthorizationCode = function (authorizationCode) {
        this.authorizationCode = authorizationCode;
    };
    Client.prototype.exchangeAuthCode = function () {
        var _this = this;
        return this.getTokens({
            grant_type: 'authorization_code',
            code: this.authorizationCode
        })
            .then(function () {
            delete _this.authorizationCode;
        });
    };
    Client.prototype.exchangeClientCredentials = function () {
        return this.getTokens({
            grant_type: 'client_credentials'
        });
    };
    Client.prototype.getTokens = function (data) {
        var _this = this;
        var payload = _.merge({
            client_id: this.clientId,
            client_secret: this.clientSecret
        }, data);
        return this.requestManager.makeRequest({
            method: 'POST',
            data: payload,
            url: this.baseAuthUrl + "/oauth2/token"
        }, { refreshTokens: false })
            .then(function (response) {
            _this.accessToken = response.access_token;
            if (response.refresh_token)
                _this.refreshToken = response.refresh_token;
            _this.tokenExpiresAt = addMilliseconds(new Date(), response.expires_in);
        });
    };
    Client.prototype.handleTokenRefresh = function () {
        return this.getTokens({
            grant_type: 'refresh_grant',
            refresh_token: this.refreshToken
        });
    };
    return Client;
}());
exports.Client = Client;
//# sourceMappingURL=Client.js.map