"use strict";
exports.__esModule = true;
var _ = require("lodash");
var fp_1 = require("lodash/fp");
var Promise = require("bluebird");
var axios_1 = require("axios");
var qs = require("qs");
var https_1 = require("https");
var ClientError_1 = require("./utils/ClientError");
var clientVersion = require('../package.json').version;
var isBrowser = this instanceof Window;
exports.defaultAxiosConfig = {
    headers: { 'User-Agent': "Y LIFT Javascript SDK v" + clientVersion },
    httpsAgent: new https_1.Agent({ keepAlive: true, rejectUnauthorized: true }),
    maxRedirects: 0,
    responseType: 'json',
    timeout: 10000,
    paramsSerializer: function (params) { return qs.stringify(params, { indices: true, strict: false, encode: true }); }
};
var RequestManager = (function () {
    function RequestManager(client, config) {
        this.client = client;
        var axiosConfig = fp_1.flow(fp_1.merge({ baseURL: client.baseApiUrl }), fp_1.defaults(exports.defaultAxiosConfig))(config.request);
        if (isBrowser)
            _.unset(axiosConfig, 'headers.User-Agent');
        this.axios = axios_1["default"].create(axiosConfig);
    }
    RequestManager.prototype.makeRequest = function (requestOptions, options) {
        var _this = this;
        if (options === void 0) { options = {}; }
        if (options.refreshTokens == undefined)
            options.refreshTokens = true;
        return Promise.resolve()
            .then(function () {
            var axiosOptions = _this.buildAxiosOptions(requestOptions);
            var token = _this.client.accessToken;
            if (token)
                _.set(axiosOptions, 'headers.Authorization', "Bearer " + token);
            return _this.axios.request(axiosOptions);
        })
            .then(function (response) { return response.data; })["catch"](function (_a) {
            var response = _a.response;
            console.error(response.data, { requestOptions: requestOptions, options: options });
            throw new ClientError_1.ClientError(response.data.message, response.data.type);
        });
    };
    RequestManager.prototype.buildAxiosOptions = function (options) {
        var rawParams = options.params || {};
        var urlParams = _.pickBy(rawParams, function (value, key) {
            return _.includes(options.url, "{" + key);
        });
        var queryParams = _.omit(rawParams, _.keys(urlParams));
        return {
            data: options.data,
            method: options.method,
            params: queryParams,
            url: this.buildUrl(options.url, urlParams)
        };
    };
    RequestManager.prototype.buildUrl = function (url, params) {
        if (params === void 0) { params = {}; }
        return _.reduce(params, function (url, value, key) { return _.replace(url, "{" + key + "}", value); }, url);
    };
    return RequestManager;
}());
exports.RequestManager = RequestManager;
//# sourceMappingURL=RequestManager.js.map