import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Profile } from "./Profile";
export interface AccountSubscription {
    id: string;
    createdAt: Date;
    updatedAt: Date;
    profileId: number;
    profile?: Profile;
    accountPlanId: number;
    status: 'active' | 'canceled' | 'unpaid';
    currentPeriodStartAt: Date | null;
    currentPeriodEndAt: Date | null;
    canceledAt: Date | null;
}
export interface AccountSubscriptionListAttributes extends YLIFTListAttributes {
    profileId?: number;
}
export interface AccountSubscriptionCreateAttributes extends YLIFTCreateAttributes {
    profileId: number;
    accountPlanId: number;
    status?: 'active' | 'canceled' | 'unpaid';
    currentPeriodStartAt?: Date | null;
    currentPeriodEndAt?: Date | null;
    canceledAt?: Date | null;
}
export interface AccountSubscriptionUpdateAttributes extends YLIFTUpdateAttributes {
    profileId?: number;
    accountPlanId?: number;
    status?: 'active' | 'canceled' | 'unpaid';
    currentPeriodStartAt?: Date | null;
    currentPeriodEndAt?: Date | null;
    canceledAt?: Date | null;
}
export declare class AccountSubscriptionResource extends Resource<AccountSubscription, AccountSubscriptionListAttributes, AccountSubscriptionCreateAttributes, AccountSubscriptionUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: AccountSubscriptionListAttributes): Promise<{
        count: number;
        rows: AccountSubscription[];
    }>;
    create(createArgs: AccountSubscriptionCreateAttributes): Promise<AccountSubscription>;
    get(id: string | number): Promise<AccountSubscription>;
    update(id: string | number, updateArgs: AccountSubscriptionUpdateAttributes): Promise<AccountSubscription>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
