import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Profile } from "./Profile";
export interface Address {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    profileId: number;
    profile?: Profile;
    line1: string;
    line2?: string | null;
    city: string;
    state: string;
    zip: string;
    phone: string | null;
    allerganId: string | null;
}
export interface AddressListAttributes extends YLIFTListAttributes {
    name?: string;
    profileId?: number;
}
export interface AddressCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    line1: string;
    line2?: string | null;
    city: string | null;
    state: string;
    zip: string;
    phone?: string | null;
    allerganId?: string;
    profileId?: number;
}
export interface AddressUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    line1?: string;
    line2?: string | null;
    city?: string;
    state?: string;
    zip?: string;
    phone?: string;
    allerganId?: string;
}
export declare class AddressResource extends Resource<Address, AddressListAttributes, AddressCreateAttributes, AddressUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: AddressListAttributes): Promise<{
        count: number;
        rows: Address[];
    }>;
    create(createArgs: AddressCreateAttributes): Promise<Address>;
    get(id: string | number): Promise<Address>;
    update(id: string | number, updateArgs: AddressUpdateAttributes): Promise<Address>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
