import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { BannerRoleAttribute, BannerRoleAttributeUpdateAttributes } from "./Banner";
export interface Banner {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    imageUrl: string;
    position: number;
    destinationPath: string | null;
    backgroundColor: string;
}
export interface BannerRoleAttribute {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    bannerId: number;
    role: String;
    isActive?: boolean;
}
export interface BannerRoleAttributeUpdateAttributes {
    bannerId: number;
    role: String;
    isActive?: boolean;
}
export interface BannerListAttributes extends YLIFTListAttributes {
}
export interface BannerCreateAttributes extends YLIFTCreateAttributes {
    imageUrl: string;
    position: number;
    destinationPath?: string;
    backgroundColor?: string;
}
export interface BannerUpdateAttributes extends YLIFTUpdateAttributes {
    imageUrl?: string;
    position?: number;
    destinationPath?: string;
    backgroundColor?: string;
}
export declare class BannerResource extends Resource<Banner, BannerListAttributes, BannerCreateAttributes, BannerUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: BannerListAttributes): Promise<{
        count: number;
        rows: Banner[];
    }>;
    create(createArgs: BannerCreateAttributes): Promise<Banner>;
    get(id: string | number): Promise<Banner>;
    update(id: string | number, updateArgs: BannerUpdateAttributes): Promise<Banner>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
    getRoleAttributes(bannerId: number): Promise<BannerRoleAttribute[]>;
    updateRoleAttribute(updateArgs: BannerRoleAttributeUpdateAttributes): Promise<BannerRoleAttribute[]>;
}
