import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
export interface Clinic {
    id: number;
    profileId: number;
    name: string;
    doctorName: string;
    line1: string;
    city: string;
    state: string;
    zip: string;
    phone: string;
    email: string;
    DEA: string;
    NPI: string;
    createdAt: Date;
    updatedAt: Date;
}
export interface ClinicListAttributes extends YLIFTListAttributes {
    profileId?: number;
    id?: number;
}
export interface ClinicGetAttributes {
    id: number;
    profileId: number;
}
export interface ClinicCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    doctorName: string;
    line1: string;
    city: string;
    state: string;
    zip: string;
    phone: string;
    email: string;
    DEA: string;
    NPI: string;
}
export interface ClinicUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    doctorName?: string;
    line1?: string;
    city?: string;
    state?: string;
    zip?: string;
    phone?: string;
    email?: string;
    DEA?: string;
    NPI?: string;
}
export declare class ClinicResource extends Resource<Clinic, ClinicListAttributes, ClinicCreateAttributes, ClinicUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: ClinicListAttributes): Promise<{
        count: number;
        rows: Clinic[];
    }>;
    create(createArgs: ClinicCreateAttributes): Promise<Clinic>;
    get(getArgs: ClinicGetAttributes): Promise<Clinic>;
    update(id: string | number, updateArgs: ClinicUpdateAttributes): Promise<Clinic>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
