import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Product } from './Product';
import { Sku } from './Sku';
export interface CombinedDiscountItem {
    id: number;
    combinedDiscountId: number;
    productId: number;
    skuId: number;
    parentProductId: number;
    parentSkuId: number;
    threshold: number;
    quantity: number;
    type: 'THRESHOLD' | 'QUANTITY';
    price: number;
    createdAt: Date;
    updatedAt: Date;
    product: Product;
    parentProduct: Product;
    sku: Sku;
    parentSku: Sku;
}
export interface CombinedDiscountItemListAttributes extends YLIFTListAttributes {
    combinedDiscountId?: number;
}
export interface CombinedDiscountItemCreateAttributes extends YLIFTCreateAttributes {
    combinedDiscountId: number;
    productId: number;
    skuId: number;
    parentProductId: number;
    parentSkuId: number;
    threshold: number;
    type: 'THRESHOLD' | 'QUANTITY';
    quantity: number;
    price: number;
}
export interface CombinedDiscountItemUpdateAttributes extends YLIFTUpdateAttributes {
    productId: number;
    skuId: number;
    parentProductId: number;
    parentSkuId: number;
    threshold: number;
    type: 'THRESHOLD' | 'QUANTITY';
    quantity: number;
    price: number;
}
export declare class CombinedDiscountItemResource extends Resource<CombinedDiscountItem, CombinedDiscountItemListAttributes, CombinedDiscountItemCreateAttributes, CombinedDiscountItemUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: CombinedDiscountItemListAttributes): Promise<{
        count: number;
        rows: CombinedDiscountItem[];
    }>;
    create(createArgs: CombinedDiscountItemCreateAttributes): Promise<CombinedDiscountItem>;
    get(id: string | number): Promise<CombinedDiscountItem>;
    update(id: string | number, updateArgs: CombinedDiscountItemUpdateAttributes): Promise<CombinedDiscountItem>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
