import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { ProfileLicense } from "./ProfileLicense";
export interface License {
    domain: 'ADDRESS' | 'GLOBAL' | 'STATE';
    createdAt: Date;
    updatedAt: Date;
    expirationEditable: boolean;
    name: string;
    valueEditable: boolean;
    profileLicenese?: ProfileLicense[];
}
export interface LicenseListAttributes extends YLIFTListAttributes {
}
export interface LicenseCreateAttributes extends YLIFTCreateAttributes {
    expirationEditable: boolean;
    name: string;
    valueEditable: boolean;
}
export interface LicenseUpdateAttributes extends YLIFTUpdateAttributes {
    expirationEditable?: boolean;
    name?: string;
    valueEditable?: boolean;
}
export declare class LicenseResource extends Resource<License, LicenseListAttributes, LicenseCreateAttributes, LicenseUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: LicenseListAttributes): Promise<{
        count: number;
        rows: License[];
    }>;
    create(createArgs: LicenseCreateAttributes): Promise<License>;
    get(id: string | number): Promise<License>;
    update(id: string | number, updateArgs: LicenseUpdateAttributes): Promise<License>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
