import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
export interface NetworkFile {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    title: string;
    caption: string | null;
    description: string | null;
    url: string;
    mimeType: string | null;
    views: number;
    size: number;
    isDownloadable: boolean | null;
    thumbnailUrl: string | null;
}
export interface NetworkFileTag {
    networkFileId: number;
    tag: string;
    createdAt: Date;
    updatedAt: Date;
}
export interface NetworkFileListAttributes extends YLIFTListAttributes {
    productBrandId?: number;
    tags?: string[];
    query?: string;
}
export interface NetworkFileCreateAttributes extends YLIFTCreateAttributes {
    title: string;
    caption?: string;
    description?: string;
    url: string;
    mimeType?: string;
    views: number;
    size: number;
    isDownloadable?: boolean;
    thumbnailUrl?: string;
}
export interface NetworkFileUpdateAttributes extends YLIFTUpdateAttributes {
    title?: string;
    caption?: string;
    description?: string;
    url?: string;
    mimeType?: string;
    views?: number;
    size?: number;
    isDownloadable?: boolean;
    thumbnailUrl?: string;
}
export interface NetworkFileUpdateBrandsAttributes {
    productBrandIds: number[];
}
export interface NetworkFileUpdateTrainingsAttributes {
    trainingIds: string[];
}
export interface NetworkFileUpdateProductsAttributes {
    productIds: number[];
}
export interface NetworkFileUpdateRolesAttributes {
    roles: string[];
}
export interface NetworkFileUpdateTagsAttributes {
    tags: string[];
}
export declare class NetworkFileResource extends Resource<NetworkFile, NetworkFileListAttributes, NetworkFileCreateAttributes, NetworkFileUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: NetworkFileListAttributes): Promise<{
        count: number;
        rows: NetworkFile[];
    }>;
    listTags(): Promise<{
        count: number;
        rows: NetworkFileTag[];
    }>;
    create(createArgs: NetworkFileCreateAttributes): Promise<NetworkFile>;
    get(id: string | number): Promise<NetworkFile>;
    update(id: string | number, updateArgs: NetworkFileUpdateAttributes): Promise<NetworkFile>;
    updateBrands(id: string | number, updateBrandsArgs: NetworkFileUpdateBrandsAttributes): Promise<NetworkFile>;
    updateTrainings(id: string | number, updateTrainingArgs: NetworkFileUpdateTrainingsAttributes): Promise<NetworkFile>;
    updateProducts(id: string | number, updateProductsArgs: NetworkFileUpdateProductsAttributes): Promise<NetworkFile>;
    updateRoles(id: string | number, updateRolesArgs: NetworkFileUpdateRolesAttributes): Promise<NetworkFile>;
    updateTags(id: string | number, updateTagsArgs: NetworkFileUpdateTagsAttributes): Promise<NetworkFile>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
