import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { OrderItem } from "./OrderItem";
import { OrderAddress } from './OrderAddress';
export interface Order {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    status: 'PENDING' | 'COMPLETED' | 'AWAITING_APPROVAL' | 'CANCELED';
    orderItems?: OrderItem[];
    orderAddress?: OrderAddress;
    amount: number;
    canceledAt?: Date;
    approvedAt?: Date;
    completedAt?: Date;
    cardId: string;
    customerId: string;
    orderAddressId: number;
    label: string;
    eventId?: string;
    subscriptionId?: number;
    prescriptionId?: number;
}
export interface OrderGetAttributes {
    id: number;
    profileId: number;
}
export interface OrderListAttributes extends YLIFTListAttributes {
    status?: 'PENDING' | 'COMPLETED' | 'AWAITING_APPROVAL' | 'CANCELED';
    cardId?: string;
    customerId?: string;
    orderAddressId?: number;
    label?: string;
    subscriptionId?: number;
    prescriptionId?: number;
    profileId?: number;
    productId?: number;
    createdBefore?: Date;
    createdAfter?: Date;
    id?: number;
}
export interface OrderSearchAttributes extends YLIFTListAttributes {
    id?: number;
    profileId?: number;
    sort?: string;
    price?: string;
}
export interface OrderCreateAttributes extends YLIFTCreateAttributes {
    cardId: string;
    addressId: string;
}
export interface OrderUpdateAttributes extends YLIFTUpdateAttributes {
    status: 'PENDING' | 'COMPLETED' | 'AWAITING_APPROVAL' | 'CANCELED';
}
export interface LeaseCreateAttributes {
    companyInfo: {
        name: string;
        yearsInBusiness: number;
        businessType: 'Proprietorship' | 'Partnership' | 'Corporation' | 'Other';
        address: string;
        line2?: string;
        city: string;
        state: string;
        zip: string;
        phone: string;
        fax?: string;
        email: string;
        taxId: string;
        grossRevenue: number;
        personalIncome: number;
    };
    leaseInfo: {
        termLength: '36 Months' | '48 Months' | '60 Months';
    };
    personalInfo: {
        firstName: string;
        lastName: string;
        phone: string;
        licenseNumber: string;
        line1: string;
        line2?: string;
        city: string;
        state: string;
        zip: string;
        ssn: string;
        dob: Date;
    };
    productInfo: {
        skuId: number;
        quantity: number;
    };
}
export declare class OrderResource extends Resource<Order, OrderListAttributes, OrderCreateAttributes, OrderUpdateAttributes> {
    constructor(requestManager: RequestManager);
    search(searchArgs: OrderSearchAttributes): Promise<{
        count: number;
        rows: Order[];
    }>;
    list(listArgs: OrderListAttributes): Promise<{
        count: number;
        rows: Order[];
    }>;
    create(createArgs: OrderCreateAttributes): Promise<Order>;
    applyForLease(createArgs: LeaseCreateAttributes): Promise<Order>;
    get(getArgs: OrderGetAttributes): Promise<Order>;
    update(id: string | number, updateArgs: OrderUpdateAttributes): Promise<Order>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
