import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Profile } from "./Profile";
export interface Patient {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    DOB: Date;
    isArchived: boolean;
    name: string;
    email: string;
    phone: string;
    doctorProfileId: number;
    doctorProfile?: Profile;
}
export interface PatientListAttributes extends YLIFTListAttributes {
    doctorProfileId?: number;
}
export interface PatientCreateAttributes extends YLIFTCreateAttributes {
    DOB: Date;
    email: string;
    name: string;
    phone: string;
}
export interface PatientUpdateAttributes extends YLIFTUpdateAttributes {
    DOB?: Date;
    name?: string;
    email?: string;
    phone?: string;
}
export declare class PatientResource extends Resource<Patient, PatientListAttributes, PatientCreateAttributes, PatientUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: PatientListAttributes): Promise<{
        count: number;
        rows: Patient[];
    }>;
    create(createArgs: PatientCreateAttributes): Promise<Patient>;
    get(id: string | number): Promise<Patient>;
    update(id: string | number, updateArgs: PatientUpdateAttributes): Promise<Patient>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
