import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Patient } from "./Patient";
export interface PatientAddress {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    patientId: number;
    patient?: Patient;
    line1: string;
    line2?: string | null;
    city: string;
    state: string;
    zip: string;
    phone: string;
}
export interface PatientAddressListAttributes extends YLIFTListAttributes {
    patientId?: number;
}
export interface PatientAddressCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    line1: string;
    line2?: string | null;
    city: string;
    state: string;
    zip: string;
    phone?: string;
    patientId: number;
}
export interface PatientAddressUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    line1?: string;
    line2?: string | null;
    city?: string;
    state?: string;
    zip?: string;
    phone?: string;
}
export declare class PatientAddressResource extends Resource<PatientAddress, PatientAddressListAttributes, PatientAddressCreateAttributes, PatientAddressUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: PatientAddressListAttributes): Promise<{
        count: number;
        rows: PatientAddress[];
    }>;
    create(createArgs: PatientAddressCreateAttributes): Promise<PatientAddress>;
    get(id: string | number): Promise<PatientAddress>;
    update(id: string | number, updateArgs: PatientAddressUpdateAttributes): Promise<PatientAddress>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
