import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { PrescriptionCartItem } from "./PrescriptionCartItem";
import { Cart, CartGetProfileAttributes } from "./Cart";
export interface PrescriptionCart {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    profileId: number;
    prescriptionCartItems?: PrescriptionCartItem[];
}
export interface PrescriptionCartOrderDataAttributes {
    id: number;
    zip?: string;
}
export interface PrescriptionCartItemCreateAttributes extends YLIFTUpdateAttributes {
    quantity: number;
    skuId: number;
    directions?: string;
}
export interface PrescriptionCartItemUpdateAttributes extends YLIFTUpdateAttributes {
    id: number;
    quantity?: number;
    directions?: string;
}
export interface PrescriptionCartUpdateAttributes extends YLIFTUpdateAttributes {
    clinicId?: number;
    patientId?: number;
    shipTo?: 'clinic' | 'patient';
    shippingMethod?: 'REGULAR' | 'EXPRESS' | 'OVERNIGHT';
}
export declare class PrescriptionCartResource extends Resource<PrescriptionCart, YLIFTListAttributes, YLIFTCreateAttributes, YLIFTUpdateAttributes> {
    constructor(requestManager: RequestManager);
    get(id: number): Promise<PrescriptionCart>;
    getByProfileId(params: CartGetProfileAttributes): Promise<Cart>;
    getOrderData(params: PrescriptionCartOrderDataAttributes): Promise<PrescriptionCart>;
    getShippingSettings(): any;
    update(updateArgs: PrescriptionCartUpdateAttributes): Promise<PrescriptionCart>;
    createCartItem(createAttributes: PrescriptionCartItemCreateAttributes): Promise<PrescriptionCart>;
    deleteCartItem(id: number): Promise<PrescriptionCart>;
    updateCartItem(updateAttributes: PrescriptionCartItemUpdateAttributes): Promise<PrescriptionCart>;
}
