import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Sku } from "./Sku";
import { Product } from "./Product";
export interface PricingRule {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    skuId: number;
    sku?: Sku;
    productId: number;
    product?: Product;
    quantityRequired: number;
    amount: number;
    isArchived: boolean;
    expiresAt: Date | null;
}
export interface PricingRuleListAttributes extends YLIFTListAttributes {
    skuId?: number;
    productId?: number;
}
export interface PricingRuleCreateAttributes extends YLIFTCreateAttributes {
    skuId: number;
    productId: number;
    quantityRequired: number;
    amount: number;
    isArchived?: boolean;
    expiresAt?: Date;
}
export interface PricingRuleUpdateAttributes extends YLIFTUpdateAttributes {
    skuId?: number;
    productId?: number;
    quantityRequired?: number;
    amount?: number;
    isArchived?: boolean;
    expiresAt?: Date;
}
export declare class PricingRuleResource extends Resource<PricingRule, PricingRuleListAttributes, PricingRuleCreateAttributes, PricingRuleUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: PricingRuleListAttributes): Promise<{
        count: number;
        rows: PricingRule[];
    }>;
    create(createArgs: PricingRuleCreateAttributes): Promise<PricingRule>;
    get(id: string | number): Promise<PricingRule>;
    update(id: string | number, updateArgs: PricingRuleUpdateAttributes): Promise<PricingRule>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
