import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Sku, SkuRoleAttribute } from './Sku';
import { ProductAttribute } from "./ProductAttribute";
import { ProductSubcategory } from "./ProductSubcategory";
import { ProductBrand } from "./ProductBrand";
import { PricingRule } from "./PricingRule";
import { ProductMedia } from "./ProductMedia";
import { TaxableProductCategory } from "./TaxableProductCategory";
import { ProductShippingSetting } from "./ProductShippingSetting";
import { Vendor } from "./Vendor";
export interface Product {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    description: string | null;
    defaultSkuId: number | null;
    defaultSku?: Sku;
    isActive: boolean;
    vendorId: number | null;
    vendor?: Vendor;
    featured: boolean;
    taxableProductCategoryId: number | null;
    taxableProductCategory?: TaxableProductCategory;
    note: string | null;
    isShippable: boolean | null;
    isAdminApprovalRequired: boolean;
    prescriptionRequired: boolean;
    isLeasable: boolean;
    taxType: 'direct' | 'flowthrough';
    skus?: Sku[];
    productAttributes?: ProductAttribute[];
    productBrands?: ProductBrand[];
    productSubcategories?: ProductSubcategory[];
    pricingRules?: PricingRule[];
    productMedia?: ProductMedia[];
    productShippingSetting?: ProductShippingSetting[];
    canApplyDiscount?: boolean;
}
export interface ProductRoleAttribute {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    productId: number;
    role: String;
    isActive?: boolean;
}
export interface ProductRoleAttributeUpdateAttributes {
    productId: number;
    role: String;
    isActive?: boolean;
}
export interface ProductListAttributes extends YLIFTListAttributes {
    isActive?: boolean;
    vendorId?: number | null;
    featured?: boolean;
}
export interface ProductSearchAttributes extends YLIFTListAttributes {
    id?: number;
    query?: string;
    categories?: number[];
    subcategories?: number[];
    brands?: number[];
    filters?: string[];
    sort?: string;
    price?: string;
    ignoreRoleFilter?: boolean;
}
export interface ProductSearchSimilarAttributes extends YLIFTListAttributes {
    query?: string;
    id?: number | number[];
}
export interface ProductCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    description?: string | null;
    defaultSkuId?: number | null;
    isActive?: boolean;
    vendorId?: number | null;
    featured?: boolean;
    taxableProductCategoryId?: number | null;
    note?: string | null;
    isShippable?: boolean | null;
    isAdminApprovalRequired?: boolean;
    prescriptionRequired?: boolean;
    isLeasable?: boolean;
    taxType?: 'direct' | 'flowthrough';
}
export interface ProductUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    description?: string | null;
    defaultSkuId?: number | null;
    isActive?: boolean;
    vendorId?: number | null;
    featured?: boolean;
    taxableProductCategoryId?: number | null;
    note?: string | null;
    isShippable?: boolean | null;
    isAdminApprovalRequired?: boolean;
    prescriptionRequired?: boolean;
    isLeasable?: boolean;
    taxType?: 'direct' | 'flowthrough';
}
export declare class ProductResource extends Resource<Product, ProductListAttributes, ProductCreateAttributes, ProductUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: ProductListAttributes): Promise<{
        count: number;
        rows: Product[];
    }>;
    search(searchArgs: ProductSearchAttributes): Promise<{
        count: number;
        rows: Product[];
        aggregations: any;
    }>;
    suggest(query: string): Promise<{
        suggestions: any[];
    }>;
    similar(similarArgs: ProductSearchSimilarAttributes): Promise<{
        count: number;
        rows: Product[];
    }>;
    create(createArgs: ProductCreateAttributes): Promise<Product>;
    get(id: string | number): Promise<Product>;
    update(id: string | number, updateArgs: ProductUpdateAttributes): Promise<Product>;
    getRoleAttributes(productId: number): Promise<ProductRoleAttribute[]>;
    updateRoleAttribute(updateArgs: ProductRoleAttributeUpdateAttributes): Promise<SkuRoleAttribute[]>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
