import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Product } from "./Product";
export interface ProductAttribute {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    productId: number;
    product: Product;
    isArchived?: boolean;
}
export interface ProductAttributeGetAttributes {
    id: string;
    productId: number;
}
export interface ProductAttributeListAttributes extends YLIFTListAttributes {
    productId: number;
    name?: string;
}
export interface ProductAttributeCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    productId: number;
    isArchived?: boolean;
}
export interface ProductAttributeUpdateAttributes extends YLIFTUpdateAttributes {
    productId: number;
    name?: string;
    isArchived?: boolean;
}
export interface ProductAttributeDeleteAttributes {
    id: string;
    productId: number;
}
export declare class ProductAttributeResource extends Resource<ProductAttribute, ProductAttributeListAttributes, ProductAttributeCreateAttributes, ProductAttributeUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: ProductAttributeListAttributes): Promise<{
        count: number;
        rows: ProductAttribute[];
    }>;
    create(createArgs: ProductAttributeCreateAttributes): Promise<ProductAttribute>;
    get(getArgs: ProductAttributeGetAttributes): Promise<ProductAttribute>;
    update(id: string | number, updateArgs: ProductAttributeUpdateAttributes): Promise<ProductAttribute>;
    del(deleteArgs: ProductAttributeDeleteAttributes): Promise<void>;
    destroy(deleteArgs: ProductAttributeDeleteAttributes): Promise<void>;
}
