import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Product } from "./Product";
export interface ProductBrand {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    description: string;
    homepageDescription?: string;
    logoUrl?: string;
    position?: number;
    clicks: number;
    isActive: boolean;
    products?: Product[];
    isNavigable: boolean;
    isFeatured: boolean;
}
export interface ProductBrandListAttributes extends YLIFTListAttributes {
    isNavigable?: boolean;
    isFeatured?: boolean;
}
export interface ProductBrandCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    description: string;
    homepageDescription?: string;
    logoUrl?: string;
    position?: number;
    clicks: number;
    isActive?: boolean;
    isNavigable?: boolean;
    isFeatured?: boolean;
}
export interface ProductBrandUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    description?: string;
    homepageDescription?: string;
    logoUrl?: string;
    position?: number;
    clicks?: number;
    isActive?: boolean;
    isNavigable?: boolean;
    isFeatured?: boolean;
}
export declare class ProductBrandResource extends Resource<ProductBrand, ProductBrandListAttributes, ProductBrandCreateAttributes, ProductBrandUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: ProductBrandListAttributes): Promise<{
        count: number;
        rows: ProductBrand[];
    }>;
    create(createArgs: ProductBrandCreateAttributes): Promise<ProductBrand>;
    get(id: string | number): Promise<ProductBrand>;
    update(id: string | number, updateArgs: ProductBrandUpdateAttributes): Promise<ProductBrand>;
    decrementPosition(id: string | number): any;
    incrementPosition(id: string | number): any;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
