import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { ProductBundleItem } from "./ProductBundleItem";
export interface ProductBundle {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    price: number | null;
    productBundleItems?: ProductBundleItem[];
    type: 'CART' | 'PACKAGE' | 'PRESCRIPTION' | 'SUBSCRIPTION';
}
export interface ProductBundleListAttributes extends YLIFTListAttributes {
}
export interface ProductBundleCreateAttributes extends YLIFTCreateAttributes {
    price?: number | null;
    type: 'CART' | 'PACKAGE' | 'PRESCRIPTION' | 'SUBSCRIPTION';
}
export interface ProductBundleUpdateAttributes extends YLIFTUpdateAttributes {
    price?: number | null;
    type?: 'CART' | 'PACKAGE' | 'PRESCRIPTION' | 'SUBSCRIPTION';
}
export declare class ProductBundleResource extends Resource<ProductBundle, ProductBundleListAttributes, ProductBundleCreateAttributes, ProductBundleUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: ProductBundleListAttributes): Promise<{
        count: number;
        rows: ProductBundle[];
    }>;
    create(createArgs: ProductBundleCreateAttributes): Promise<ProductBundle>;
    get(id: string | number): Promise<ProductBundle>;
    update(id: string | number, updateArgs: ProductBundleUpdateAttributes): Promise<ProductBundle>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
