import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { ProductBundle } from "./ProductBundle";
import { Sku } from "./Sku";
export interface ProductBundleItem {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    productBundleId: number;
    productBundle?: ProductBundle;
    skuId: number;
    sku?: Sku;
    quantity: number;
}
export interface ProductBundleItemListAttributes extends YLIFTListAttributes {
    productBundleId?: number;
    skuId?: number;
    quantity?: number;
}
export interface ProductBundleItemCreateAttributes extends YLIFTCreateAttributes {
    productBundleId: number;
    skuId: number;
    quantity: number;
}
export interface ProductBundleItemUpdateAttributes extends YLIFTUpdateAttributes {
    productBundleId?: number;
    skuId?: number;
    quantity?: number;
}
export declare class ProductBundleItemResource extends Resource<ProductBundleItem, ProductBundleItemListAttributes, ProductBundleItemCreateAttributes, ProductBundleItemUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: ProductBundleItemListAttributes): Promise<{
        count: number;
        rows: ProductBundleItem[];
    }>;
    create(createArgs: ProductBundleItemCreateAttributes): Promise<ProductBundleItem>;
    get(id: string | number): Promise<ProductBundleItem>;
    update(id: string | number, updateArgs: ProductBundleItemUpdateAttributes): Promise<ProductBundleItem>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
