import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { ProductDiscountThreshold } from './ProductDiscountThreshold';
export interface ProductDiscount {
    id: number;
    productId: number;
    skuId: number;
    isActive: boolean;
    expiresAt: Date;
    productDiscountThresholds?: ProductDiscountThreshold[];
    createdAt: Date;
    updatedAt: Date;
}
export interface ProductDiscountListAttributes extends YLIFTListAttributes {
    limit?: number;
    offset?: number;
}
export interface ProductDiscountCreateAttributes extends YLIFTCreateAttributes {
    productId: number;
    skuId: number;
    isActive?: boolean;
    expiresAt?: Date;
    productDiscountThresholds?: ProductDiscountThreshold[];
}
export interface ProductDiscountUpdateAttributes extends YLIFTUpdateAttributes {
    productId?: number;
    skuId?: number;
    isActive?: boolean;
    expiresAt?: Date;
    productDiscountThresholds?: ProductDiscountThreshold[];
}
export interface CurrentDiscountAttributes {
    productDiscount: ProductDiscount;
    totalPurchaseAmount: number;
}
export declare class ProductDiscountResource extends Resource<ProductDiscount, ProductDiscountListAttributes, ProductDiscountCreateAttributes, ProductDiscountUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: ProductDiscountListAttributes): Promise<{
        count: number;
        rows: ProductDiscount[];
    }>;
    create(createArgs: ProductDiscountCreateAttributes): Promise<ProductDiscount>;
    get(id: string | number): Promise<ProductDiscount>;
    update(id: string | number, updateArgs: ProductDiscountUpdateAttributes): Promise<ProductDiscount>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
    currentDiscount(id: string | number, skuId: string | number): Promise<CurrentDiscountAttributes>;
}
