import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Product } from "./Product";
import { ProductMedia } from "./ProductMedia";
export interface ProductMedia {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    productId: number;
    product?: Product;
    url: string;
    type: 'image' | 'video';
    groupId: string;
    label: string;
    width?: number;
    height?: number;
    mimeType?: string;
    isActive: boolean;
    isDefault: boolean;
    loads: number;
    views: number;
    clicks: number;
}
export interface ProductMediaListAttributes extends YLIFTListAttributes {
    productId?: number;
    type?: 'image' | 'video';
    groupId?: string;
    mimeType?: string;
}
export interface ProductMediaCreateAttributes extends YLIFTCreateAttributes {
    productId: number;
    url: string;
    type: 'image' | 'video';
    groupId: string;
    label: string;
    width?: number;
    height?: number;
    mimeType?: string;
    isActive: boolean;
    isDefault: boolean;
    loads: number;
    views: number;
    clicks: number;
}
export interface ProductMediaUpdateAttributes extends YLIFTUpdateAttributes {
    productId?: number;
    url?: string;
    type?: 'image' | 'video';
    groupId?: string;
    label?: string;
    width?: number;
    height?: number;
    mimeType?: string;
    isActive?: boolean;
    isDefault?: boolean;
    loads?: number;
    views?: number;
    clicks?: number;
}
export declare class ProductMediaResource extends Resource<ProductMedia, ProductMediaListAttributes, ProductMediaCreateAttributes, ProductMediaUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: ProductMediaListAttributes): Promise<{
        count: number;
        rows: ProductMedia[];
    }>;
    create(createArgs: ProductMediaCreateAttributes): Promise<ProductMedia>;
    get(id: string | number): Promise<ProductMedia>;
    update(id: string | number, updateArgs: ProductMediaUpdateAttributes): Promise<ProductMedia>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
