import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
export interface Profile {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string | null;
    email: string;
    phone: string | null;
    timezone: string;
    isEmailConfirmed: boolean;
    lastLogin: Date | null;
    loginCount: number;
    lastActive: Date | null;
    customerId: string;
    parentProfileId: number | null;
}
export interface ProfileListAttributes extends YLIFTListAttributes {
    email?: string;
    name?: string;
    role?: string;
    customerId?: number;
    parentProfileId?: number;
}
export interface ProfileCreateAttributes extends YLIFTCreateAttributes {
    email: string;
    name?: string | null;
    phone?: string | null;
    timezone?: string;
    isEmailConfirmed?: boolean;
    customerId?: string;
    lastLogin?: Date | null;
    loginCount?: number;
    lastActive?: Date | null;
    parentProfileId?: number | null;
}
export interface ProfileUpdateAttributes extends YLIFTUpdateAttributes {
    email?: string;
    name?: string | null;
    phone?: string | null;
    timezone?: string;
    isEmailConfirmed?: boolean;
    customerId?: string;
    lastLogin?: Date | null;
    loginCount?: number;
    lastActive?: Date | null;
    parentProfileId?: number | null;
}
export interface CardCreateAttributes extends YLIFTCreateAttributes {
    profileId?: number;
    cardNumber: string;
    cardCvc: string;
    cardExpMonth: string;
    cardExpYear: string;
    addressFirstName: string;
    addressLastName: string;
    addressLine: string;
    addressCity: string;
    addressState: string;
    addressZip: string;
}
export interface ProfileUpdateEmailAttributes {
    email: string;
    profileId: number;
}
export interface PendingInviteRecord {
    id: string;
    profileId: number;
    email: string;
    createdAt: Date;
    updatedAt: Date;
}
export declare class ProfileResource extends Resource<Profile, ProfileListAttributes, ProfileCreateAttributes, ProfileUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: ProfileListAttributes): Promise<{
        count: number;
        rows: Profile[];
    }>;
    create(createArgs: ProfileCreateAttributes): Promise<Profile>;
    me(): Promise<Profile>;
    role(): Promise<Profile>;
    get(id: string | number): Promise<Profile>;
    update(id: string | number, updateArgs: ProfileUpdateAttributes): Promise<Profile>;
    updateEmail(updateEmailArgs: ProfileUpdateEmailAttributes): Promise<Profile>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
    listCards(listArgs: {
        profileId?: number;
    }): any;
    createCard(createArgs: CardCreateAttributes): any;
    deleteCard(cardId: string): any;
    recruitUser(email: string): any;
    pendingInvites(profileId?: number): Promise<PendingInviteRecord[]>;
}
