import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
export interface PromoCode {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    code: string;
    amount: number;
    limit: number;
    validAfter: Date | null;
    validUntil: Date | null;
    discountType: 'CENTS' | 'PERCENT';
    isActive: boolean;
}
export interface PromoCodeListAttributes extends YLIFTListAttributes {
    isActive?: boolean;
}
export interface PromoCodeCreateAttributes extends YLIFTCreateAttributes {
    code: string;
    amount: number;
    limit: number;
    validAfter?: Date | null;
    validUntil?: Date | null;
    discountType: 'CENTS' | 'PERCENT';
    isActive?: boolean;
}
export interface PromoCodeUpdateAttributes extends YLIFTUpdateAttributes {
    code?: string;
    amount?: number;
    limit?: number;
    validAfter?: Date | null;
    validUntil?: Date | null;
    discountType?: 'CENTS' | 'PERCENT';
    isActive?: boolean;
}
export declare class PromoCodeResource extends Resource<PromoCode, PromoCodeListAttributes, PromoCodeCreateAttributes, PromoCodeUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: PromoCodeListAttributes): Promise<{
        count: number;
        rows: PromoCode[];
    }>;
    create(createArgs: PromoCodeCreateAttributes): Promise<PromoCode>;
    get(id: string | number): Promise<PromoCode>;
    redeem(code: string): Promise<PromoCode>;
    clear(code: string): Promise<PromoCode>;
    update(id: string | number, updateArgs: PromoCodeUpdateAttributes): Promise<PromoCode>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
