import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Profile } from './Profile';
export interface ResaleCertificate {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    profileId: number;
    profile?: Profile;
    state: string;
    attachmentUrl: string | null;
    message: string | null;
    expiresAt: Date | null;
    status: 'REQUESTED' | 'APPROVED' | 'REJECTED' | 'EXPIRED' | 'DEACTIVATED';
    label: string;
    handledAt: Date | null;
    handleMessage: string | null;
}
export interface ResaleCertificateListAttributes extends YLIFTListAttributes {
    profileId?: number;
    state?: string;
    status?: 'REQUESTED' | 'APPROVED' | 'REJECTED' | 'EXPIRED' | 'DEACTIVATED';
    createdBefore?: Date;
    createdAfter?: Date;
    expiresBefore?: Date;
    expiresAfter?: Date;
    expired?: Boolean;
}
export interface ResaleCertificateCreateAttributes extends YLIFTCreateAttributes {
    profileId: number;
    state: string;
    attachmentUrl: string | null;
    message?: string | null;
    expiresAt?: Date | null;
    handledAt?: Date | null;
    handleMessage?: string | null;
}
export interface ResaleCertificateUpdateAttributes extends YLIFTUpdateAttributes {
    profileId?: number;
    state?: string;
    attachmentUrl?: string | null;
    message?: string | null;
    expiresAt?: Date | null;
    status?: 'REQUESTED' | 'APPROVED' | 'REJECTED' | 'EXPIRED' | 'DEACTIVATED';
    handledAt?: Date | null;
    handleMessage?: string | null;
}
export interface ResaleCertificateApproveAttributes extends YLIFTUpdateAttributes {
    message?: string | null;
    expiresAt?: Date | null;
}
export interface ResaleCertificateRejectAttributes extends YLIFTUpdateAttributes {
    message?: string | null;
}
export declare class ResaleCertificateResource extends Resource<ResaleCertificate, ResaleCertificateListAttributes, ResaleCertificateCreateAttributes, ResaleCertificateUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: ResaleCertificateListAttributes): Promise<{
        count: number;
        rows: ResaleCertificate[];
    }>;
    create(createArgs: ResaleCertificateCreateAttributes): Promise<ResaleCertificate>;
    get(id: string | number): Promise<ResaleCertificate>;
    update(id: string | number, updateArgs: ResaleCertificateUpdateAttributes): Promise<ResaleCertificate>;
    approve(id: string | number, approveArgs: ResaleCertificateApproveAttributes): any;
    reject(id: string | number, rejectArgs: ResaleCertificateRejectAttributes): any;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
