import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
export interface SalesAccount {
    id: string;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    email: string | null;
    phone: string | null;
    description: string | null;
    website: string | null;
    numberOfEmployees: number | null;
    estimatedRevenue: number | null;
    primaryProfileId: number | null;
    salesRepProfileId: number;
}
export interface SalesAccountListAttributes extends YLIFTListAttributes {
    name?: string;
    salesRepProfileId?: number;
    sortBy?: string;
    sortDir?: string;
}
export interface SalesAccountCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    email?: string | null;
    phone?: string | null;
    description?: string | null;
    website?: string | null;
    numberOfEmployees?: number | null;
    estimatedRevenue?: number | null;
    primaryProfileId?: number | null;
    salesRepProfileId: number;
}
export interface SalesAccountUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    email?: string | null;
    phone?: string | null;
    description?: string | null;
    website?: string | null;
    numberOfEmployees?: number | null;
    estimatedRevenue?: number | null;
    primaryProfileId?: number | null;
    salesRepProfileId?: number;
}
export declare class SalesAccountResource extends Resource<SalesAccount, SalesAccountListAttributes, SalesAccountCreateAttributes, SalesAccountUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: SalesAccountListAttributes): Promise<{
        count: number;
        rows: SalesAccount[];
    }>;
    create(createArgs: SalesAccountCreateAttributes): Promise<SalesAccount>;
    get(id: string | number): Promise<SalesAccount>;
    update(id: string | number, updateArgs: SalesAccountUpdateAttributes): Promise<SalesAccount>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
