import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Product } from "./Product";
import { ProductMedia } from "./ProductMedia";
import { PricingRule } from "./PricingRule";
import { SkuProductAttributeDescription } from './SkuProductAttributeDescription';
export interface Sku {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    productId: number;
    product?: Product;
    price: number;
    defaultProductMediaId: number | null;
    defaultProductMedia?: ProductMedia;
    isActive: boolean | null;
    retailPrice: number | null;
    taxablePrice: number | null;
    isArchived: boolean | null;
    cost: number | null;
    isResellable: boolean;
    quantityIncrement: number;
    quantityMin: number;
    quantityMax: number;
    skuProductAttributeDescriptions: SkuProductAttributeDescription[];
}
export interface SkuRoleAttribute {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    skuId: number;
    roleName: String;
    isActive?: boolean;
    price?: number;
}
export interface SkuListAttributes extends YLIFTListAttributes {
    productId?: number;
    isActive?: boolean;
}
export interface SkuCreateAttributes extends YLIFTCreateAttributes {
    productId: number;
    price: number;
    defaultProductMediaId?: number | null;
    isActive?: boolean | null;
    retailPrice?: number | null;
    taxablePrice?: number | null;
    isArchived?: boolean | null;
    cost?: number | null;
    isResellable?: boolean;
    quantityIncrement?: number;
    quantityMin?: number;
    quantityMax?: number;
}
export interface SkuUpdateAttributes extends YLIFTUpdateAttributes {
    productId?: number;
    price?: number;
    defaultProductMediaId?: number | null;
    isActive?: boolean | null;
    retailPrice?: number | null;
    taxablePrice?: number | null;
    isArchived?: boolean | null;
    cost?: number | null;
    isResellable?: boolean;
    quantityIncrement?: number;
    quantityMin?: number;
    quantityMax?: number;
}
export interface SkuRoleAttributeUpdateAttributes extends YLIFTUpdateAttributes {
    skuId: number;
    roleName: String;
    isActive?: boolean;
    price?: number;
}
export declare class SkuResource extends Resource<Sku, SkuListAttributes, SkuCreateAttributes, SkuUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: SkuListAttributes): Promise<{
        count: number;
        rows: Sku[];
    }>;
    create(createArgs: SkuCreateAttributes): Promise<Sku>;
    get(id: string | number): Promise<Sku>;
    getPricingRules(skuId: number): Promise<PricingRule[]>;
    getRoleAttributes(skuId: number): Promise<SkuRoleAttribute[]>;
    update(id: string | number, updateArgs: SkuUpdateAttributes): Promise<Sku>;
    updateRoleAttribute(updateArgs: SkuRoleAttributeUpdateAttributes): Promise<SkuRoleAttribute[]>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
