import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Profile } from "./Profile";
import { ProductBundle } from "./ProductBundle";
import { Address } from "./Address";
export interface Subscription {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    profileId: number;
    profile?: Profile;
    productBundleId: number;
    productBundle?: ProductBundle;
    addressId: number;
    address?: Address;
    name: string | null;
    cardId: string;
    frequency: number;
    frequencyUnit: 'days' | 'weeks' | 'months' | 'years';
    cancelDate: Date | null;
    lastOrderDate: Date | null;
    nextOrderDate: Date | null;
    status: 'ACTIVE' | 'CANCELED';
}
export interface SubscriptionListAttributes extends YLIFTListAttributes {
    profileId?: number;
    productBundleId?: number;
    addressId?: number;
    cardId?: string;
    status?: 'ACTIVE' | 'CANCELED';
}
export interface SubscriptionCreateAttributes extends YLIFTCreateAttributes {
    profileId: number;
    productBundleId: number;
    addressId: number;
    name?: string | null;
    cardId: string;
    frequency: number;
    frequencyUnit: 'days' | 'weeks' | 'months' | 'years';
    cancelDate?: Date | null;
    lastOrderDate?: Date | null;
    nextOrderDate?: Date | null;
    status: 'ACTIVE' | 'CANCELED';
}
export interface SubscriptionUpdateAttributes extends YLIFTUpdateAttributes {
    profileId?: number;
    productBundleId?: number;
    addressId?: number;
    name?: string | null;
    cardId?: string;
    frequency?: number;
    frequencyUnit?: 'days' | 'weeks' | 'months' | 'years';
    cancelDate?: Date | null;
    lastOrderDate?: Date | null;
    nextOrderDate?: Date | null;
    status?: 'ACTIVE' | 'CANCELED';
}
export declare class SubscriptionResource extends Resource<Subscription, SubscriptionListAttributes, SubscriptionCreateAttributes, SubscriptionUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: SubscriptionListAttributes): Promise<{
        count: number;
        rows: Subscription[];
    }>;
    create(createArgs: SubscriptionCreateAttributes): Promise<Subscription>;
    get(id: string | number): Promise<Subscription>;
    update(id: string | number, updateArgs: SubscriptionUpdateAttributes): Promise<Subscription>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
