import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Order } from "./Order";
export interface Training {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    overview: string;
    categoryId: string;
    locationId: string;
    timezone: string;
    price: number;
    isActive: boolean;
    hasLiveStream: boolean;
    startTime: Date;
    endTime: Date;
    profileId: number;
    approvedByAdmin: string;
}
export interface TrainingListAttributes extends YLIFTListAttributes {
    categoryId?: string;
    locationId?: string;
    isActive?: boolean;
    hasLiveStream?: boolean;
    before?: Date;
    after?: Date;
    isPurchased?: boolean;
    createdByMe?: boolean;
    approvedByAdmin?: string;
    getDiscount?: boolean;
}
export interface TrainingCreateAttributes extends YLIFTCreateAttributes {
    overview?: string;
    categoryId: string;
    locationId?: string;
    timezone?: string;
    price?: number;
    isActive?: boolean;
    hasLiveStream?: boolean;
    startTime?: Date;
    endTime?: Date;
}
export interface TrainingOrderAttributes {
    cardId: string;
    trainingId: string;
    addressId: number;
}
export interface TrainingUpdateAttributes extends YLIFTUpdateAttributes {
    overview?: string;
    categoryId?: string;
    locationId?: string;
    timezone?: string;
    price?: number;
    isActive?: boolean;
    hasLiveStream?: boolean;
    startTime?: Date;
    endTime?: Date;
}
export declare class TrainingResource extends Resource<Training, TrainingListAttributes, TrainingCreateAttributes, TrainingUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: TrainingListAttributes): Promise<{
        count: number;
        rows: Training[];
    }>;
    create(createArgs: TrainingCreateAttributes): Promise<Training>;
    checkAccessible(id: string): Promise<{
        accessible: boolean;
    }>;
    order(orderArgs: TrainingOrderAttributes): Promise<Order>;
    get(id: string | number): Promise<Training>;
    update(id: string | number, updateArgs: TrainingUpdateAttributes): Promise<Training>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
