import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
export interface TrainingLecture {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    trainingId: string;
    title: string;
    description: string;
    thumbnailUrl: string;
    contentUrl: string;
    contentType: string;
    isActive: boolean;
    isFree: boolean;
    trainingModuleId: string;
}
export interface TrainingLectureListAttributes extends YLIFTListAttributes {
    trainingId?: string;
}
export interface TrainingLectureViewListAttributes extends YLIFTListAttributes {
    trainingLectureId?: string;
    profileId?: string;
    trainingModuleId?: string;
}
export interface TrainingLectureCreateAttributes extends YLIFTCreateAttributes {
    trainingId: string;
    title?: string;
    description?: string;
    thumbnailUrl?: string;
    contentUrl?: string;
    contentType?: string;
    isActive?: boolean;
    isFree?: boolean;
    trainingModuleId?: string;
}
export interface TrainingLectureUpdateAttributes extends YLIFTUpdateAttributes {
    trainingId?: string;
    title?: string;
    description?: string;
    thumbnailUrl?: string;
    contentUrl?: string;
    contentType?: string;
    isActive?: boolean;
    isFree?: boolean;
    trainingModuleId?: string;
}
export declare class TrainingLectureResource extends Resource<TrainingLecture, TrainingLectureListAttributes, TrainingLectureCreateAttributes, TrainingLectureUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: TrainingLectureListAttributes): Promise<{
        count: number;
        rows: TrainingLecture[];
    }>;
    create(createArgs: TrainingLectureCreateAttributes): Promise<TrainingLecture>;
    get(id: string | number): Promise<TrainingLecture>;
    update(id: string | number, updateArgs: TrainingLectureUpdateAttributes): Promise<TrainingLecture>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
    trackView(id: string): Promise<void>;
    getViews(listArgs: TrainingLectureViewListAttributes): Promise<void>;
}
