import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Profile } from './Profile';
export interface RatedTraining {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    overview: string;
    categoryId: string;
    locationId: string;
    timezone: string;
    price: number;
    isActive: boolean;
    hasLiveStream: boolean;
    startTime: Date;
    endTime: Date;
    rate: number;
}
export interface RateRecord {
    comment: string;
    id: number;
    profileId: number;
    rate: number;
    trainingId: string;
    updatedAt: Date;
    createdAt: Date;
    profile: Profile;
}
export interface ReviewMark {
    rate: number;
    count: number;
}
export interface TrainingRatingsListAttributes extends YLIFTListAttributes {
    trainingId: string;
}
export interface TrainingRatingCreateAttributes extends YLIFTCreateAttributes {
    trainingId: string;
    rate: number;
    comment?: string;
}
export interface TrainingRatingDeleteAttributes {
    trainingId: string;
}
export interface TrainingRatingMyAttributes extends YLIFTListAttributes {
    trainingId: string;
}
export interface TrainingRatingMarksAttributes extends YLIFTListAttributes {
    trainingId: string;
}
export interface TrainingRatingRatedAttributes extends YLIFTListAttributes {
    categoryId: string;
    limit?: number;
    offset?: number;
}
export declare class TrainingRatingsResource extends Resource<RateRecord, TrainingRatingsListAttributes, TrainingRatingCreateAttributes, TrainingRatingCreateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: TrainingRatingsListAttributes): Promise<RateRecord[]>;
    create(createArgs: TrainingRatingCreateAttributes): Promise<{
        success: boolean;
    }>;
    update(createArgs: TrainingRatingCreateAttributes): Promise<{
        success: boolean;
    }>;
    my(listArgs: TrainingRatingMyAttributes): Promise<RateRecord>;
    marks(markArgs: TrainingRatingMarksAttributes): Promise<ReviewMark[]>;
    del(delArgs: TrainingRatingDeleteAttributes): Promise<{
        success: boolean;
    }>;
    rated(ratedArgs: TrainingRatingRatedAttributes): Promise<RatedTraining[]>;
}
