import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
export interface Vendor {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string | null;
    position: number | null;
    orderWindowStartTime: string | null;
    orderWindowEndTime: string | null;
    isPreferred: boolean;
}
export interface VendorListAttributes extends YLIFTListAttributes {
    name?: string | null;
}
export interface VendorCreateAttributes extends YLIFTCreateAttributes {
    name?: string | null;
    position?: number | null;
    orderWindowStartTime?: string | null;
    orderWindowEndTime?: string | null;
    isPreferred?: boolean;
}
export interface VendorUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string | null;
    position?: number | null;
    orderWindowStartTime?: string | null;
    orderWindowEndTime?: string | null;
    isPreferred?: boolean;
}
export interface VendorEmailSettings {
    id: number;
    displayUnitPrice: boolean;
    displayVendorCost: boolean;
    displayTaxAmount: boolean;
    displayShippingAmount: boolean;
    displayMedicalLicense: boolean;
    vendorId: number;
    createdAt: Date;
    updatedAt: Date;
}
export interface VendorEmailSettingsUpdateAttributes extends YLIFTUpdateAttributes {
    displayUnitPrice?: boolean;
    displayVendorCost?: boolean;
    displayTaxAmount?: boolean;
    displayShippingAmount?: boolean;
    displayMedicalLicense?: boolean;
}
export declare class VendorResource extends Resource<Vendor, VendorListAttributes, VendorCreateAttributes, VendorUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: VendorListAttributes): Promise<{
        count: number;
        rows: Vendor[];
    }>;
    create(createArgs: VendorCreateAttributes): Promise<Vendor>;
    get(id: string | number): Promise<Vendor>;
    getEmailSettings(vendorId: number): Promise<VendorEmailSettings>;
    update(id: string | number, updateArgs: VendorUpdateAttributes): Promise<Vendor>;
    updateEmailSettings(updateArgs: VendorEmailSettingsUpdateAttributes): Promise<VendorEmailSettings>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
