import * as Promise from 'bluebird';
import { YLIFTCreateAttributes, YLIFTListAttributes, YLIFTUpdateAttributes, Resource } from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Vendor } from "./Vendor";
export interface VendorAddress {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string | null;
    vendorId: number;
    vendor?: Vendor;
    line1: string;
    line2: string | null;
    city: string;
    state: string;
    zip: string;
    phone: string | null;
    email: string;
    shippoObjectId: string | null;
}
export interface VendorAddressListAttributes extends YLIFTListAttributes {
    name?: string | null;
    vendorId?: number | null;
    state?: string | null;
    zip?: string | null;
    email?: string | null;
}
export interface VendorAddressCreateAttributes extends YLIFTCreateAttributes {
    name?: string | null;
    vendorId: number;
    line1: string;
    line2?: string | null;
    city: string;
    state: string;
    zip: string;
    phone?: string | null;
    email: string;
    shippoObjectId?: string | null;
}
export interface VendorAddressUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string | null;
    vendorId?: number;
    line1?: string;
    line2?: string | null;
    city?: string;
    state?: string;
    zip?: string;
    phone?: string | null;
    email?: string;
    shippoObjectId?: string | null;
}
export declare class VendorAddressResource extends Resource<VendorAddress, VendorAddressListAttributes, VendorAddressCreateAttributes, VendorAddressUpdateAttributes> {
    constructor(requestManager: RequestManager);
    list(listArgs: VendorAddressListAttributes): Promise<{
        count: number;
        rows: VendorAddress[];
    }>;
    create(createArgs: VendorAddressCreateAttributes): Promise<VendorAddress>;
    get(id: string | number): Promise<VendorAddress>;
    update(id: string | number, updateArgs: VendorAddressUpdateAttributes): Promise<VendorAddress>;
    del(id: string | number): Promise<void>;
    destroy(id: string | number): Promise<void>;
}
