import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';

export interface AccountPlan {
    id: string;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    roleName: string;
    price: number;
    interval: 'month'|'year'|'once';
    intervalCount: number;
}

export interface AccountPlanListAttributes extends YLIFTListAttributes {
    name?: string;
}

export interface AccountPlanCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    roleName: string;
    price: number;
    interval?: 'month'|'year'|'once';
    intervalCount?: number;
}

export interface AccountPlanUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    roleName?: string;
    price?: number;
    interval?: 'month'|'year'|'once';
    intervalCount?: number;
}

export class AccountPlanResource extends Resource<AccountPlan, AccountPlanListAttributes, AccountPlanCreateAttributes, AccountPlanUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/accounts/plans', requestManager);
    }

    public list(listArgs: AccountPlanListAttributes): Promise<{ count: number, rows: AccountPlan[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: AccountPlanCreateAttributes): Promise<AccountPlan> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<AccountPlan> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: AccountPlanUpdateAttributes): Promise<AccountPlan> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
