import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Profile} from "./Profile";

export interface AccountSubscription {
    id: string;
    createdAt: Date;
    updatedAt: Date;
    profileId: number;
    profile?: Profile;
    accountPlanId: number;
    status: 'active'|'canceled'|'unpaid';
    currentPeriodStartAt: Date|null;
    currentPeriodEndAt: Date|null;
    canceledAt: Date|null;
}

export interface AccountSubscriptionListAttributes extends YLIFTListAttributes {
    profileId?: number;
}

export interface AccountSubscriptionCreateAttributes extends YLIFTCreateAttributes {
    profileId: number;
    accountPlanId: number;
    status?: 'active'|'canceled'|'unpaid';
    currentPeriodStartAt?: Date|null;
    currentPeriodEndAt?: Date|null;
    canceledAt?: Date|null;
}

export interface AccountSubscriptionUpdateAttributes extends YLIFTUpdateAttributes {
    profileId?: number;
    accountPlanId?: number;
    status?: 'active'|'canceled'|'unpaid';
    currentPeriodStartAt?: Date|null;
    currentPeriodEndAt?: Date|null;
    canceledAt?: Date|null;
}

export class AccountSubscriptionResource extends Resource<AccountSubscription, AccountSubscriptionListAttributes, AccountSubscriptionCreateAttributes, AccountSubscriptionUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/accounts/subscriptions', requestManager);
    }

    public list(listArgs: AccountSubscriptionListAttributes): Promise<{ count: number, rows: AccountSubscription[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: AccountSubscriptionCreateAttributes): Promise<AccountSubscription> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<AccountSubscription> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: AccountSubscriptionUpdateAttributes): Promise<AccountSubscription> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
