import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Profile} from "./Profile";

export interface Address {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    profileId: number;
    profile?: Profile;
    line1: string;
    line2?: string | null;
    city: string;
    state: string;
    zip: string;
    phone: string|null;
    allerganId: string|null;
}

export interface AddressListAttributes extends YLIFTListAttributes {
    name?: string;
    profileId?: number;
}

export interface AddressCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    line1: string;
    line2?: string | null;
    city: string|null;
    state: string;
    zip: string;
    phone?: string|null;
    allerganId?: string;
    profileId?: number;
}

export interface AddressUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    line1?: string;
    line2?: string | null;
    city?: string;
    state?: string;
    zip?: string;
    phone?: string;
    allerganId?: string;
}

export class AddressResource extends Resource<Address, AddressListAttributes, AddressCreateAttributes, AddressUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/addresses', requestManager);
    }

    public list(listArgs: AddressListAttributes): Promise<{ count: number, rows: Address[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: AddressCreateAttributes): Promise<Address> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<Address> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: AddressUpdateAttributes): Promise<Address> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
