import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { BannerRoleAttribute, BannerRoleAttributeUpdateAttributes } from "./Banner";

export interface Banner {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    imageUrl: string;
    position: number;
    destinationPath: string|null;
    backgroundColor: string;
}

export interface BannerRoleAttribute {
  id: number;
  createdAt: Date;
  updatedAt: Date;
  bannerId: number;
  role: String;
  isActive?: boolean;
}

export interface BannerRoleAttributeUpdateAttributes {
  bannerId: number;
  role: String;
  isActive?: boolean;
}

export interface BannerListAttributes extends YLIFTListAttributes {
}

export interface BannerCreateAttributes extends YLIFTCreateAttributes {
    imageUrl: string;
    position: number;
    destinationPath?: string;
    backgroundColor?: string;
}

export interface BannerUpdateAttributes extends YLIFTUpdateAttributes {
    imageUrl?: string;
    position?: number;
    destinationPath?: string;
    backgroundColor?: string;
}

export class BannerResource extends Resource<Banner, BannerListAttributes, BannerCreateAttributes, BannerUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/banners', requestManager);
    }

    public list(listArgs: BannerListAttributes): Promise<{ count: number, rows: Banner[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: BannerCreateAttributes): Promise<Banner> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<Banner> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: BannerUpdateAttributes): Promise<Banner> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }

  public getRoleAttributes(bannerId: number): Promise<BannerRoleAttribute[]> {
    return this.makeRequest({
      method: 'GET',
      params: {bannerId},
      url: `${this.basePath}/role-attributes`
    })
  }

  public updateRoleAttribute(updateArgs: BannerRoleAttributeUpdateAttributes): Promise<BannerRoleAttribute[]> {
    return this.makeRequest({
      method: 'PUT',
      data: updateArgs,
      url: `${this.basePath}/role-attributes`
    })
  }
}
