import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Sku} from "./Sku";
import {PricingRule} from "./PricingRule";

export interface CartItem {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    cartId: number;
    skuId: number;
    sku?: Sku;
    quantity: number;
}

export interface CartItemListAttributes extends YLIFTListAttributes {
    cartId?: number;
}

export interface CartItemCreateAttributes extends YLIFTCreateAttributes {
    cartId: number;
    skuId: number;
    quantity: number;
}

export interface CartItemUpdateAttributes extends YLIFTUpdateAttributes {
    cartId: number;
    quantity: number;
}

export class CartItemResource extends Resource<CartItem, CartItemListAttributes, CartItemCreateAttributes, CartItemUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/carts/{cartId}/items', requestManager);
    }

    public list(listArgs: CartItemListAttributes): Promise<{ count: number, rows: CartItem[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: CartItemCreateAttributes): Promise<CartItem> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<CartItem> {
        return this._get(id);
    }

    public getApplicablePricingRules(id: number): Promise<PricingRule[]> {
        return this.makeRequest({
            method: 'GET',
            params: {id},
            url: `/carts/items/{id}/pricing-rules`
        })
    }

    public update(id: string | number, updateArgs: CartItemUpdateAttributes): Promise<CartItem> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
