import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {head} from 'lodash';

export interface Clinic {
    id: number;
    profileId: number;
    name: string;
    doctorName: string;
    line1: string;
    city: string;
    state: string;
    zip: string;
    phone: string;
    email: string;
    DEA: string;
    NPI: string;
    createdAt: Date;
    updatedAt: Date;
}

export interface ClinicListAttributes extends YLIFTListAttributes {
    profileId?: number;
    id?: number;
}

export interface ClinicGetAttributes {
    id: number;
    profileId: number;
}

export interface ClinicCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    doctorName: string;
    line1: string;
    city: string;
    state: string;
    zip: string;
    phone: string;
    email: string;
    DEA: string;
    NPI: string;
}

export interface ClinicUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    doctorName?: string;
    line1?: string;
    city?: string;
    state?: string;
    zip?: string;
    phone?: string;
    email?: string;
    DEA?: string;
    NPI?: string;
}

export class ClinicResource extends Resource<Clinic, ClinicListAttributes, ClinicCreateAttributes, ClinicUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/clinics', requestManager);
    }

    public list(listArgs: ClinicListAttributes): Promise<{ count: number, rows: Clinic[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ClinicCreateAttributes): Promise<Clinic> {
        return this._create(createArgs);
    }

    public get(getArgs: ClinicGetAttributes): Promise<Clinic> {
        return this._list(getArgs)
            .then(({ rows: clinics, count }) => {
                return head(clinics);
            })
    }

    public update(id: string | number, updateArgs: ClinicUpdateAttributes): Promise<Clinic> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
