import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  YLIFTUpdateAttributes,
  Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';

import { CombinedDiscountItem } from './CombinedDiscountItem';

export interface CombinedDiscount {
  id: number;
  name: string;
  isActive: boolean;
  expiresAt: Date;
  createdAt: Date;
  updatedAt: Date;
  combinedDiscountItems?: CombinedDiscountItem[];
}

export interface CombinedDiscountListAttributes extends YLIFTListAttributes {
  limit?: number;
  offset?: number;
}

export interface CombinedDiscountCreateAttributes extends YLIFTCreateAttributes {
  name: string;
  isActive: boolean;
  expiresAt: Date;
}

export interface CombinedDiscountUpdateAttributes extends YLIFTUpdateAttributes {
  name?: string;
  isActive?: boolean;
  expiresAt?: Date;
}

export class CombinedDiscountResource extends Resource<CombinedDiscount, CombinedDiscountListAttributes, CombinedDiscountCreateAttributes, CombinedDiscountUpdateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/combined-discounts', requestManager);
  }

  public list(listArgs: CombinedDiscountListAttributes): Promise<{ count: number, rows: CombinedDiscount[] }> {
    return this._list(listArgs);
  }

  public create(createArgs: CombinedDiscountCreateAttributes): Promise<CombinedDiscount> {
    return this._create(createArgs);
  }

  public get(id: string | number): Promise<CombinedDiscount> {
    return this._get(id);
  }

  public update(id: string | number, updateArgs: CombinedDiscountUpdateAttributes): Promise<CombinedDiscount> {
    return this._update(id, updateArgs);
  }

  public del(id: string | number): Promise<void> {
    return this.destroy(id);
  }

  public destroy(id: string | number): Promise<void> {
    return this._destroy(id);
  }
}
