import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';

export interface EnvironmentSettings {
  id: string;
  recruitersCommissionFee: number;
  systemCommissionFee: number;
}

export interface EnvironmentSettingsCreateAttributes extends YLIFTCreateAttributes {
  recruitersCommissionFee?: number;
  systemCommissionFee?: number;
}

export class EnvironmentSettingsResource extends Resource<EnvironmentSettings, any, EnvironmentSettingsCreateAttributes, any> {
  constructor(requestManager: RequestManager) {
    super('/environment-settings', requestManager);
  }

  public create(createArgs: EnvironmentSettingsCreateAttributes): Promise<EnvironmentSettings> {
    return this._create(createArgs);
  }

  public update(updateArgs: EnvironmentSettingsCreateAttributes): Promise<EnvironmentSettings> {
    return this._create(updateArgs);
  }

  public get(): Promise<EnvironmentSettings> {
    return this.makeRequest({
      method: 'GET',
      url: `${this.basePath}`
    });
  }
}
