import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {ProfileLicense} from "./ProfileLicense";

export interface License {
    domain: 'ADDRESS'|'GLOBAL'|'STATE';
    createdAt: Date;
    updatedAt: Date;
    expirationEditable: boolean;
    name: string;
    valueEditable: boolean;
    profileLicenese?: ProfileLicense[];
}

export interface LicenseListAttributes extends YLIFTListAttributes {

}

export interface LicenseCreateAttributes extends YLIFTCreateAttributes {
    expirationEditable: boolean;
    name: string;
    valueEditable: boolean;
}

export interface LicenseUpdateAttributes extends YLIFTUpdateAttributes {
    expirationEditable?: boolean;
    name?: string;
    valueEditable?: boolean;
}

export class LicenseResource extends Resource<License, LicenseListAttributes, LicenseCreateAttributes, LicenseUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/licenses', requestManager);
    }

    public list(listArgs: LicenseListAttributes): Promise<{ count: number, rows: License[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: LicenseCreateAttributes): Promise<License> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<License> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: LicenseUpdateAttributes): Promise<License> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
