import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Sku} from "./Sku";
import {Product} from "./Product";
import {PromoCode} from "./PromoCode";
import {TaxExemptionRule} from "./TaxExemptionRule";
import {PricingRule} from "./PricingRule";
import {ResaleCertificate} from "./ResaleCertificate";
import {Vendor} from "./Vendor";

export interface OrderItem {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    orderId: number;
    skuId: number;
    sku?: Sku;
    quantity: number;
    amount: number;
    type: 'SKU'|'TAX'|'SHIPPING'|'PROMO'|'PRICING_RULE';
    productId: number|null;
    product?: Product;
    promoCodeId: number|null;
    promoCode?: PromoCode;
    taxExemptionRuleId: number|null;
    taxExemptionRule?: TaxExemptionRule;
    taxRate: number|null;
    pricingRuleId: number|null;
    pricingRule?: PricingRule;
    resaleCertificateId: number|null;
    resaleCertificate?: ResaleCertificate;
    unitVendorCost: number|null;
    unitPrice: number|null;
    unitTaxablePrice: number|null;
    taxAmount: number|null;
    vendorId: number|null;
    vendor?: Vendor;
}

export interface OrderItemListAttributes extends YLIFTListAttributes {
    orderId?: number;
    productId?: number;
    skuId?: number;
    createdBefore?: Date;
    createdAfter?: Date;
    completedBefore?: Date;
    completedAfter?: Date;
}

export class OrderItemResource extends Resource<OrderItem, OrderItemListAttributes, YLIFTCreateAttributes, YLIFTUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/orders/{orderId}/items', requestManager);
    }

    public list(listArgs: OrderItemListAttributes): Promise<{ count: number, rows: OrderItem[] }> {
        return this._list(listArgs);
    }

    public get(id: string | number): Promise<OrderItem> {
        return this._get(id);
    }
}
