import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Profile} from "./Profile";

export interface Patient {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    DOB: Date;
    isArchived: boolean;
    name: string;
    email: string;
    phone: string;
    doctorProfileId: number;
    doctorProfile?: Profile;
}

export interface PatientListAttributes extends YLIFTListAttributes {
    doctorProfileId?: number;
}

export interface PatientCreateAttributes extends YLIFTCreateAttributes {
    DOB: Date;
    email: string;
    name: string;
    phone: string;
}

export interface PatientUpdateAttributes extends YLIFTUpdateAttributes {
    DOB?: Date;
    name?: string;
    email?: string;
    phone?: string;
}

export class PatientResource extends Resource<Patient, PatientListAttributes, PatientCreateAttributes, PatientUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/patients', requestManager);
    }

    public list(listArgs: PatientListAttributes): Promise<{ count: number, rows: Patient[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: PatientCreateAttributes): Promise<Patient> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<Patient> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: PatientUpdateAttributes): Promise<Patient> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
