import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Patient} from "./Patient";

export interface PatientAllergy {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    allergy: string;
    patientId: number;
    patient?: Patient;
}

export interface PatientAllergyListAttributes extends YLIFTListAttributes {
    allergy?: string;
    patientId?: number;
}

export interface PatientAllergyCreateAttributes extends YLIFTCreateAttributes {
    allergy: string;
    patientId: number;
}

export interface PatientAllergyUpdateAttributes extends YLIFTUpdateAttributes {
    allergy?: string;
    patientId?: number;
}

export class PatientAllergyResource extends Resource<PatientAllergy, PatientAllergyListAttributes, PatientAllergyCreateAttributes, PatientAllergyUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/patient-allergies', requestManager);
    }

    public list(listArgs: PatientAllergyListAttributes): Promise<{ count: number, rows: PatientAllergy[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: PatientAllergyCreateAttributes): Promise<PatientAllergy> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<PatientAllergy> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: PatientAllergyUpdateAttributes): Promise<PatientAllergy> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
