import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface Plan {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    price: number;
    interval: string;
    intervalCount: number;
}

export interface PlanListAttributes extends YLIFTListAttributes {
}

export interface PlanCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    price?: number;
    interval?: string;
    intervalCount?: number;
}

export interface PlanUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    price?: number;
    interval?: string;
    intervalCount?: number;
}


export class PlanResource extends Resource<Plan, PlanListAttributes, PlanCreateAttributes, PlanUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/plans', requestManager);
    }

    public list(listArgs: PlanListAttributes): Promise<{ count: number, rows: Plan[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: PlanCreateAttributes): Promise<Plan> {
        return this._create(createArgs);
    }

    public update(id: string | number, updateArgs: PlanUpdateAttributes): Promise<Plan> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
