import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Clinic} from "./Clinic";
import {Profile} from "./Profile";
import {Patient} from "./Patient";
import {OrderAddress} from "./OrderAddress";
import {Order} from './Order';

export interface Prescription {
    id: number;
    clinicId: number;
    clinic?: Clinic;
    doctorProfileId: number;
    doctorProfile?: Profile;
    patientId: number;
    patient?: Patient;
    orderAddressId: number;
    orderAddress?: OrderAddress;
    shipTo: string;
    shippingMethod: string;
    createdAt: Date;
    updatedAt: Date;
}

export interface PrescriptionListAttributes extends YLIFTListAttributes {
    doctorProfileId?: number;
    id?: number;
}

export interface PrescriptionCreateAttributes extends YLIFTCreateAttributes {
    cardId: string;
}

export class PrescriptionResource extends Resource<Prescription, PrescriptionListAttributes, PrescriptionCreateAttributes, {}> {
    constructor(requestManager: RequestManager) {
        super('/prescriptions', requestManager);
    }

    public list(listArgs: PrescriptionListAttributes): Promise<{ count: number, rows: Prescription[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: PrescriptionCreateAttributes): Promise<Order> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<Prescription> {
        return this._get(id);
    }
}
