import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Sku} from "./Sku";

export interface PrescriptionCartItem {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    prescriptionCartId: number;
    skuId: number;
    sku?: Sku;
    quantity: number;
}

export interface PrescriptionCartItemListAttributes extends YLIFTListAttributes {
    prescriptionCartId?: number;
}

export interface PrescriptionCartItemCreateAttributes extends YLIFTCreateAttributes {
    prescriptionCartId: number;
    skuId: number;
    quantity: number;
}

export interface PrescriptionCartItemUpdateAttributes extends YLIFTUpdateAttributes {
    quantity: number;
}

export class PrescriptionCartItemResource extends Resource<PrescriptionCartItem, PrescriptionCartItemListAttributes,
    PrescriptionCartItemCreateAttributes, PrescriptionCartItemUpdateAttributes> {

    constructor(requestManager: RequestManager) {
        super('/prescription-carts/{prescriptionCartId}/items', requestManager);
    }

    public list(listArgs: PrescriptionCartItemListAttributes): Promise<{ count: number, rows: PrescriptionCartItem[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: PrescriptionCartItemCreateAttributes): Promise<PrescriptionCartItem> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<PrescriptionCartItem> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: PrescriptionCartItemUpdateAttributes): Promise<PrescriptionCartItem> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
