import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Sku} from "./Sku";
import {Product} from "./Product";

export interface PricingRule {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    skuId: number;
    sku?: Sku;
    productId: number;
    product?: Product;
    quantityRequired: number;
    amount: number;
    isArchived: boolean;
    expiresAt: Date|null;
}

export interface PricingRuleListAttributes extends YLIFTListAttributes {
    skuId?: number;
    productId?: number;
}

export interface PricingRuleCreateAttributes extends YLIFTCreateAttributes {
    skuId: number;
    productId: number;
    quantityRequired: number;
    amount: number;
    isArchived?: boolean;
    expiresAt?: Date;
}

export interface PricingRuleUpdateAttributes extends YLIFTUpdateAttributes {
    skuId?: number;
    productId?: number;
    quantityRequired?: number;
    amount?: number;
    isArchived?: boolean;
    expiresAt?: Date;
}

export class PricingRuleResource extends Resource<PricingRule, PricingRuleListAttributes, PricingRuleCreateAttributes, PricingRuleUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/pricing-rules', requestManager);
    }

    public list(listArgs: PricingRuleListAttributes): Promise<{ count: number, rows: PricingRule[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: PricingRuleCreateAttributes): Promise<PricingRule> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<PricingRule> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: PricingRuleUpdateAttributes): Promise<PricingRule> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
