import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Product} from "./Product";

export interface ProductBrand {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    description: string;
    homepageDescription?: string;
    logoUrl?: string;
    position?: number;
    clicks: number;
    isActive: boolean;
    products?: Product[];
    isNavigable: boolean;
    isFeatured: boolean;
}

export interface ProductBrandListAttributes extends YLIFTListAttributes {
    isNavigable?: boolean;
    isFeatured?: boolean;
}

export interface ProductBrandCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    description: string;
    homepageDescription?: string;
    logoUrl?: string;
    position?: number;
    clicks: number;
    isActive?: boolean;
    isNavigable?: boolean;
    isFeatured?: boolean;
}

export interface ProductBrandUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    description?: string;
    homepageDescription?: string;
    logoUrl?: string;
    position?: number;
    clicks?: number;
    isActive?: boolean;
    isNavigable?: boolean;
    isFeatured?: boolean;
}

export class ProductBrandResource extends Resource<ProductBrand, ProductBrandListAttributes, ProductBrandCreateAttributes, ProductBrandUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/products/brands', requestManager);
    }

    public list(listArgs: ProductBrandListAttributes): Promise<{ count: number, rows: ProductBrand[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ProductBrandCreateAttributes): Promise<ProductBrand> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<ProductBrand> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: ProductBrandUpdateAttributes): Promise<ProductBrand> {
        return this._update(id, updateArgs);
    }

    public decrementPosition(id: string | number) {
        return this.makeRequest({
            method: 'PUT',
            url: `${this.basePath}/${id}/decrement-position`
        })
    }

    public incrementPosition(id: string | number) {
        return this.makeRequest({
            method: 'PUT',
            url: `${this.basePath}/${id}/increment-position`
        })
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
