import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Product} from "./Product";
import {ProductBrand} from "./ProductBrand";

export interface ProductBrandMedia {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    productBrandId: number;
    productBrand?: ProductBrand;
    url: string;
    mimeType?: string;
}

export interface ProductBrandMediaListAttributes extends YLIFTListAttributes {
    productBrandId?: number;
    mimeType?: string;
}

export interface ProductBrandMediaCreateAttributes extends YLIFTCreateAttributes {
    productBrandId: number;
    url: string;
    mimeType?: string;
}

export interface ProductBrandMediaUpdateAttributes extends YLIFTUpdateAttributes {
    productBrandId?: number;
    url?: string;
    mimeType?: string;
}

export class ProductBrandMediaResource extends Resource<ProductBrandMedia, ProductBrandMediaListAttributes, ProductBrandMediaCreateAttributes, ProductBrandMediaUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/products/brands/media', requestManager);
    }

    public list(listArgs: ProductBrandMediaListAttributes): Promise<{ count: number, rows: ProductBrandMedia[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ProductBrandMediaCreateAttributes): Promise<ProductBrandMedia> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<ProductBrandMedia> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: ProductBrandMediaUpdateAttributes): Promise<ProductBrandMedia> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
