import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Product} from "./Product";
import {ProductBundleItem} from "./ProductBundleItem";

export interface ProductBundle {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    price: number|null;
    productBundleItems?: ProductBundleItem[];
    type: 'CART'|'PACKAGE'|'PRESCRIPTION'|'SUBSCRIPTION';
}

export interface ProductBundleListAttributes extends YLIFTListAttributes {
}

export interface ProductBundleCreateAttributes extends YLIFTCreateAttributes {
    price?: number|null;
    type: 'CART'|'PACKAGE'|'PRESCRIPTION'|'SUBSCRIPTION';
}

export interface ProductBundleUpdateAttributes extends YLIFTUpdateAttributes {
    price?: number|null;
    type?: 'CART'|'PACKAGE'|'PRESCRIPTION'|'SUBSCRIPTION';
}

export class ProductBundleResource extends Resource<ProductBundle, ProductBundleListAttributes, ProductBundleCreateAttributes, ProductBundleUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/products/bundles', requestManager);
    }

    public list(listArgs: ProductBundleListAttributes): Promise<{ count: number, rows: ProductBundle[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ProductBundleCreateAttributes): Promise<ProductBundle> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<ProductBundle> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: ProductBundleUpdateAttributes): Promise<ProductBundle> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
