import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {ProductBundle} from "./ProductBundle";
import {Sku} from "./Sku";

export interface ProductBundleItem {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    productBundleId: number;
    productBundle?: ProductBundle;
    skuId: number;
    sku?: Sku;
    quantity: number;
}

export interface ProductBundleItemListAttributes extends YLIFTListAttributes {
    productBundleId?: number;
    skuId?: number;
    quantity?: number;
}

export interface ProductBundleItemCreateAttributes extends YLIFTCreateAttributes {
    productBundleId: number;
    skuId: number;
    quantity: number;
}

export interface ProductBundleItemUpdateAttributes extends YLIFTUpdateAttributes {
    productBundleId?: number;
    skuId?: number;
    quantity?: number;
}

export class ProductBundleItemResource extends Resource<ProductBundleItem, ProductBundleItemListAttributes, ProductBundleItemCreateAttributes, ProductBundleItemUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/products/bundles/{productBundleId}/items', requestManager);
    }

    public list(listArgs: ProductBundleItemListAttributes): Promise<{ count: number, rows: ProductBundleItem[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ProductBundleItemCreateAttributes): Promise<ProductBundleItem> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<ProductBundleItem> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: ProductBundleItemUpdateAttributes): Promise<ProductBundleItem> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
