import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Product} from "./Product";

export interface ProductCategory {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    isActive: boolean;
    isFeatured: boolean;
    clicks: number;
    position?: number;
    isArchived: boolean;
}

export interface ProductCategoryListAttributes extends YLIFTListAttributes {
    name?: string;
    isActive?: boolean;
    isFeatured?: boolean;
    isArchived?: boolean;
}

export interface ProductCategoryCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    isActive: boolean;
    isFeatured: boolean;
    clicks: number;
    position?: number;
    isArchived: boolean;
}

export interface ProductCategoryUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    isActive?: boolean;
    isFeatured?: boolean;
    clicks?: number;
    position?: number;
    isArchived?: boolean;
}

export class ProductCategoryResource extends Resource<ProductCategory, ProductCategoryListAttributes, ProductCategoryCreateAttributes, ProductCategoryUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/products/categories', requestManager);
    }

    public list(listArgs: ProductCategoryListAttributes): Promise<{ count: number, rows: ProductCategory[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ProductCategoryCreateAttributes): Promise<ProductCategory> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<ProductCategory> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: ProductCategoryUpdateAttributes): Promise<ProductCategory> {
        return this._update(id, updateArgs);
    }

    public decrementPosition(id: string | number) {
        return this.makeRequest({
            method: 'PUT',
            url: `${this.basePath}/${id}/decrement-position`
        })
    }

    public incrementPosition(id: string | number) {
        return this.makeRequest({
            method: 'PUT',
            url: `${this.basePath}/${id}/increment-position`
        })
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
