import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Product} from "./Product";
import {Profile} from "./Profile";

export interface ProductClick {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    productId: number;
    product?: Product;
    profileId: number|null;
    profile?: Profile;
    anonymousId: string|null;
}

export interface ProductClickListAttributes extends YLIFTListAttributes {
    productId?: number;
    profileId?: number;
    anonymousId?: string;
}

export interface ProductClickCreateAttributes extends YLIFTCreateAttributes {
    productId: number;
    profileId?: number;
    anonymousId?: string;
}

export interface ProductClickUpdateAttributes extends YLIFTUpdateAttributes {
    productId?: number;
    profileId?: number;
    anonymousId?: string;
}

export class ProductClickResource extends Resource<ProductClick, ProductClickListAttributes, ProductClickCreateAttributes, ProductClickUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/products/{productId}/clicks', requestManager);
    }

    public list(listArgs: ProductClickListAttributes): Promise<{ count: number, rows: ProductClick[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ProductClickCreateAttributes): Promise<ProductClick> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<ProductClick> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: ProductClickUpdateAttributes): Promise<ProductClick> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
