import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  YLIFTUpdateAttributes,
  Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { ProductDiscountThreshold } from './ProductDiscountThreshold';

export interface ProductDiscount {
  id: number;
  productId: number;
  skuId: number;
  isActive: boolean;
  expiresAt: Date;
  productDiscountThresholds?: ProductDiscountThreshold[];
  createdAt: Date;
  updatedAt: Date;
}

export interface ProductDiscountListAttributes extends YLIFTListAttributes {
  limit?: number;
  offset?: number;
}

export interface ProductDiscountCreateAttributes extends YLIFTCreateAttributes {
  productId: number;
  skuId: number;
  isActive?: boolean;
  expiresAt?: Date;
  productDiscountThresholds?: ProductDiscountThreshold[]
}

export interface ProductDiscountUpdateAttributes extends YLIFTUpdateAttributes {
  productId?: number;
  skuId?: number;
  isActive?: boolean;
  expiresAt?: Date;
  productDiscountThresholds?: ProductDiscountThreshold[];
}

export interface CurrentDiscountAttributes {
  productDiscount: ProductDiscount;
  totalPurchaseAmount: number;
}

export class ProductDiscountResource extends Resource<ProductDiscount, ProductDiscountListAttributes, ProductDiscountCreateAttributes, ProductDiscountUpdateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/products/discounts', requestManager);
  }

  public list(listArgs: ProductDiscountListAttributes): Promise<{ count: number, rows: ProductDiscount[] }> {
    return this._list(listArgs);
  }

  public create(createArgs: ProductDiscountCreateAttributes): Promise<ProductDiscount> {
    return this._create(createArgs);
  }

  public get(id: string | number): Promise<ProductDiscount> {
    return this._get(id);
  }

  public update(id: string | number, updateArgs: ProductDiscountUpdateAttributes): Promise<ProductDiscount> {
    return this._update(id, updateArgs);
  }

  public del(id: string | number): Promise<void> {
    return this.destroy(id);
  }

  public destroy(id: string | number): Promise<void> {
    return this._destroy(id);
  }

  public currentDiscount(id: string | number, skuId: string | number): Promise<CurrentDiscountAttributes> {
    return this.makeRequest({
      method: 'GET',
      url: `${this.basePath}/current-discount/${id}/${skuId}`
    })
  }
}
