import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  YLIFTUpdateAttributes,
  Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';

export interface ProductDiscountThreshold {
  productDiscountId: number;
  amount: number;
  threshold: number;
  createdAt: Date;
  updatedAt: Date;
}

export interface ProductDiscountThresholdListAttributes extends YLIFTListAttributes {
  limit?: number;
  offset?: number;
}

export interface ProductDiscountThresholdCreateAttributes extends YLIFTCreateAttributes {
  productDiscountId: number;
  amount: number;
  threshold: number;
}

export interface ProductDiscountThresholdUpdateAttributes extends YLIFTUpdateAttributes {
  amount: number;
  threshold: number;
}

export class ProductDiscountThresholdResource extends Resource<
  ProductDiscountThreshold,
  ProductDiscountThresholdListAttributes,
  ProductDiscountThresholdCreateAttributes,
  ProductDiscountThresholdUpdateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/products/discounts/thresholds', requestManager);
  }

  public list(listArgs: ProductDiscountThresholdListAttributes): Promise<{ count: number, rows: ProductDiscountThreshold[] }> {
    return this._list(listArgs);
  }

  public create(createArgs: ProductDiscountThresholdCreateAttributes): Promise<ProductDiscountThreshold> {
    return this._create(createArgs);
  }

  public get(id: string | number): Promise<ProductDiscountThreshold> {
    return this._get(id);
  }

  public update(id: string | number, updateArgs: ProductDiscountThresholdUpdateAttributes): Promise<ProductDiscountThreshold> {
    return this._update(id, updateArgs);
  }

  public del(id: string | number): Promise<void> {
    return this.destroy(id);
  }

  public destroy(id: string | number): Promise<void> {
    return this._destroy(id);
  }
}
