import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Product} from "./Product";
import {ProductMedia} from "./ProductMedia";

export interface ProductMedia {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    productId: number;
    product?: Product;
    url: string;
    type: 'image'|'video';
    groupId: string;
    label: string;
    width?: number;
    height?: number;
    mimeType?: string;
    isActive: boolean;
    isDefault: boolean;
    loads: number;
    views: number;
    clicks: number;
}

export interface ProductMediaListAttributes extends YLIFTListAttributes {
    productId?: number;
    type?: 'image'|'video';
    groupId?: string;
    mimeType?: string;
}

export interface ProductMediaCreateAttributes extends YLIFTCreateAttributes {
    productId: number;
    url: string;
    type: 'image'|'video';
    groupId: string;
    label: string;
    width?: number;
    height?: number;
    mimeType?: string;
    isActive: boolean;
    isDefault: boolean;
    loads: number;
    views: number;
    clicks: number;
}

export interface ProductMediaUpdateAttributes extends YLIFTUpdateAttributes {
    productId?: number;
    url?: string;
    type?: 'image'|'video';
    groupId?: string;
    label?: string;
    width?: number;
    height?: number;
    mimeType?: string;
    isActive?: boolean;
    isDefault?: boolean;
    loads?: number;
    views?: number;
    clicks?: number;
}

export class ProductMediaResource extends Resource<ProductMedia, ProductMediaListAttributes, ProductMediaCreateAttributes, ProductMediaUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/products/media', requestManager);
    }

    public list(listArgs: ProductMediaListAttributes): Promise<{ count: number, rows: ProductMedia[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ProductMediaCreateAttributes): Promise<ProductMedia> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<ProductMedia> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: ProductMediaUpdateAttributes): Promise<ProductMedia> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
