import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Product} from "./Product";

export interface ProductShippingSetting {
    productId: number;
    product?: Product;
    createdAt: Date;
    updatedAt: Date;
    expressRate: number|null;
    overnightRate: number|null;
    regularRate: number|null;
    groupSize: number;
}

export interface ProductShippingSettingListAttributes extends YLIFTListAttributes {
    productId?: number;
}

export interface ProductShippingSettingCreateAttributes extends YLIFTCreateAttributes {
    productId: number;
    expressRate?: number|null;
    overnightRate?: number|null;
    regularRate?: number|null;
    groupSize: number;
}

export interface ProductShippingSettingUpdateAttributes extends YLIFTUpdateAttributes {
    productId: number;
    expressRate?: number|null;
    overnightRate?: number|null;
    regularRate?: number|null;
    groupSize?: number;
}

export class ProductShippingSettingResource extends Resource<ProductShippingSetting, ProductShippingSettingListAttributes, ProductShippingSettingCreateAttributes, ProductShippingSettingUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/products/shipping-settings', requestManager);
    }

    public list(listArgs: ProductShippingSettingListAttributes): Promise<{ count: number, rows: ProductShippingSetting[] }> {
        return this._list(listArgs);
    }

    public update(updateArgs: ProductShippingSettingUpdateAttributes): Promise<ProductShippingSetting> {
        return this.makeRequest({
            method: 'PUT',
            data: updateArgs,
            url: this.basePath
        })
    }

}
