import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {ProductCategory} from "./ProductCategory";

export interface ProductSubcategory {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    productCategoryId: number;
    productCategory?: ProductCategory;
    isFeatured: boolean;
    isActive: boolean;
    clicks: number;
    position?: number;
    isArchived?: number;
}

export interface ProductSubcategoryListAttributes extends YLIFTListAttributes {
    name: string;
    productCategoryId: number;
    isFeatured: boolean;
    isActive: boolean;
    position?: number;
    isArchived?: number;
}

export interface ProductSubcategoryCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    isActive: boolean;
    isFeatured: boolean;
    clicks: number;
    position?: number;
    isArchived: boolean;
}

export interface ProductSubcategoryUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    isActive?: boolean;
    isFeatured?: boolean;
    clicks?: number;
    position?: number;
    isArchived?: boolean;
}

export class ProductSubcategoryResource extends Resource<ProductSubcategory, ProductSubcategoryListAttributes, ProductSubcategoryCreateAttributes, ProductSubcategoryUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/products/subcategories', requestManager);
    }

    public list(listArgs: ProductSubcategoryListAttributes): Promise<{ count: number, rows: ProductSubcategory[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ProductSubcategoryCreateAttributes): Promise<ProductSubcategory> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<ProductSubcategory> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: ProductSubcategoryUpdateAttributes): Promise<ProductSubcategory> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
