import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Profile} from "./Profile";

export interface ProfileEmail {
    profileId: number;
    profile?: Profile;
    createdAt: Date;
    updatedAt: Date;
    name: string|null;
    email: string;
    sendBuyingReminders: boolean;
    sendReceipts: boolean;
}

export interface ProfileEmailListAttributes extends YLIFTListAttributes {
    profileId?: number;
    name?: string|null;
    email?: string;
    sendBuyingReminders?: boolean;
    sendReceipts?: boolean;
}

export interface ProfileEmailCreateAttributes extends YLIFTCreateAttributes {
    profileId: number;
    name?: string|null;
    email: string;
    sendBuyingReminders?: boolean;
    sendReceipts?: boolean;
}

export interface ProfileEmailUpdateAttributes extends YLIFTUpdateAttributes {
    profileId: number;
    name?: string|null;
    email?: string;
    sendBuyingReminders?: boolean;
    sendReceipts?: boolean;
}

export class ProfileEmailResource extends Resource<ProfileEmail, ProfileEmailListAttributes, ProfileEmailCreateAttributes, ProfileEmailUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/profiles/emails', requestManager);
    }

    public list(listArgs: ProfileEmailListAttributes): Promise<{ count: number, rows: ProfileEmail[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ProfileEmailCreateAttributes): Promise<ProfileEmail> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<ProfileEmail> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: ProfileEmailUpdateAttributes): Promise<ProfileEmail> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
