import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Profile} from "./Profile";
import {Address} from "./Address";

export interface ProfileLicense {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    profileId: number;
    profile?: Profile;
    addressId: number|null;
    address?: Address;
    state: string|null;
    expirationDate: Date|null;
    value: string|null;
}

export interface ProfileLicenseListAttributes extends YLIFTListAttributes {
    profileId?: number;
    name?: string|null;
    license?: string;
}

export interface ProfileLicenseCreateAttributes extends YLIFTCreateAttributes {
    profileId: number;
    addressId?: number|null;
    state?: string|null;
    expirationDate?: Date|null;
    value?: string|null;
    licenseName: string;
}

export interface ProfileLicenseUpdateAttributes extends YLIFTUpdateAttributes {
    profileId?: number;
    addressId?: number|null;
    state?: string|null;
    expirationDate?: Date|null;
    value?: string|null;
    licenseName?: string;
}

export class ProfileLicenseResource extends Resource<ProfileLicense, ProfileLicenseListAttributes, ProfileLicenseCreateAttributes, ProfileLicenseUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/profiles/licenses', requestManager);
    }

    public list(listArgs: ProfileLicenseListAttributes): Promise<{ count: number, rows: ProfileLicense[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ProfileLicenseCreateAttributes): Promise<ProfileLicense> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<ProfileLicense> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: ProfileLicenseUpdateAttributes): Promise<ProfileLicense> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
