import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import {Profile} from "./Profile";
import {VendorContact} from "./VendorContact";

export interface ProfileVendorContact {
    id: number;
    profileId: number;
    profile?: Profile;
    vendorContactId: number;
    vendorContact?: VendorContact;
    createdAt: Date;
    updatedAt: Date;
}

export interface ProfileVendorContactListAttributes extends YLIFTListAttributes {
    profileId?: number;
    vendorContactId?: number;
}

export interface ProfileVendorContactCreateAttributes extends YLIFTCreateAttributes {
    profileId: number;
    vendorContactId: number;
}

export class ProfileVendorContactResource extends Resource<ProfileVendorContact, ProfileVendorContactListAttributes, ProfileVendorContactCreateAttributes, YLIFTUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/profiles/vendor-contacts', requestManager);
    }

    public list(listArgs: ProfileVendorContactListAttributes): Promise<{ count: number, rows: ProfileVendorContact[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ProfileVendorContactCreateAttributes): Promise<ProfileVendorContact> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<ProfileVendorContact> {
        return this._get(id);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
