import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface PromoCode {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    code: string;
    amount: number;
    limit: number;
    validAfter: Date | null;
    validUntil: Date | null;
    discountType: 'CENTS' | 'PERCENT';
    isActive: boolean;
}

export interface PromoCodeListAttributes extends YLIFTListAttributes {
    isActive?: boolean;
}

export interface PromoCodeCreateAttributes extends YLIFTCreateAttributes {
    code: string;
    amount: number;
    limit: number;
    validAfter?: Date | null;
    validUntil?: Date | null;
    discountType: 'CENTS' | 'PERCENT';
    isActive?: boolean;
}

export interface PromoCodeUpdateAttributes extends YLIFTUpdateAttributes {
    code?: string;
    amount?: number;
    limit?: number;
    validAfter?: Date | null;
    validUntil?: Date | null;
    discountType?: 'CENTS' | 'PERCENT';
    isActive?: boolean;
}


export class PromoCodeResource extends Resource<PromoCode, PromoCodeListAttributes, PromoCodeCreateAttributes, PromoCodeUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/promo-codes', requestManager);
    }

    public list(listArgs: PromoCodeListAttributes): Promise<{ count: number, rows: PromoCode[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: PromoCodeCreateAttributes): Promise<PromoCode> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<PromoCode> {
        return this._get(id);
    }

    public redeem(code: string): Promise<PromoCode> {
        return this.makeRequest({
            method: 'GET',
            params: {code},
            url: `${this.basePath}/redeem/{code}`
        })
    }

    public clear(code: string): Promise<PromoCode> {
        return this.makeRequest({
            method: 'DELETE',
            params: {code},
            url: `${this.basePath}/redeem/{code}`
        })
    }

    public update(id: string | number, updateArgs: PromoCodeUpdateAttributes): Promise<PromoCode> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
