import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';
import {CardCreateAttributes, Profile} from './Profile';

export interface ResaleCertificate {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    profileId: number;
    profile?: Profile;
    state: string;
    attachmentUrl: string|null;
    message: string|null;
    expiresAt: Date|null;
    status: 'REQUESTED'|'APPROVED'|'REJECTED'|'EXPIRED'|'DEACTIVATED';
    label: string;
    handledAt: Date|null;
    handleMessage: string|null;
}

export interface ResaleCertificateListAttributes extends YLIFTListAttributes {
    profileId?: number;
    state?: string;
    status?: 'REQUESTED'|'APPROVED'|'REJECTED'|'EXPIRED'|'DEACTIVATED';
    createdBefore?: Date;
    createdAfter?: Date;
    expiresBefore?: Date;
    expiresAfter?: Date;
    expired?: Boolean;
}

export interface ResaleCertificateCreateAttributes extends YLIFTCreateAttributes {
    profileId: number;
    state: string;
    attachmentUrl: string|null;
    message?: string|null;
    expiresAt?: Date|null;
    handledAt?: Date|null;
    handleMessage?: string|null;
}

export interface ResaleCertificateUpdateAttributes extends YLIFTUpdateAttributes {
    profileId?: number;
    state?: string;
    attachmentUrl?: string|null;
    message?: string|null;
    expiresAt?: Date|null;
    status?: 'REQUESTED'|'APPROVED'|'REJECTED'|'EXPIRED'|'DEACTIVATED';
    handledAt?: Date|null;
    handleMessage?: string|null;
}

export interface ResaleCertificateApproveAttributes extends YLIFTUpdateAttributes {
    message?: string|null;
    expiresAt?: Date|null;
}

export interface ResaleCertificateRejectAttributes extends YLIFTUpdateAttributes {
    message?: string|null;
}


export class ResaleCertificateResource extends Resource<ResaleCertificate, ResaleCertificateListAttributes, ResaleCertificateCreateAttributes, ResaleCertificateUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/resale-certificates', requestManager);
    }

    public list(listArgs: ResaleCertificateListAttributes): Promise<{ count: number, rows: ResaleCertificate[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ResaleCertificateCreateAttributes): Promise<ResaleCertificate> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<ResaleCertificate> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: ResaleCertificateUpdateAttributes): Promise<ResaleCertificate> {
        return this._update(id, updateArgs);
    }

    public approve(id: string | number, approveArgs: ResaleCertificateApproveAttributes) {
        return this.makeRequest({
            method: 'PUT',
            data: approveArgs,
            url: `${this.basePath}/${id}/approve`
        })
    }

    public reject(id: string | number, rejectArgs: ResaleCertificateRejectAttributes) {
        return this.makeRequest({
            method: 'PUT',
            data: rejectArgs,
            url: `${this.basePath}/${id}/reject`
        })
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
