import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';
import {Profile} from "./Profile";
import {Product} from "./Product";

export interface Review {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    profileId: number;
    profile?: Profile;
    productId: number;
    product?: Product;
    text: string;
    stars: number;
}

export interface ReviewListAttributes extends YLIFTListAttributes {
    profileId: number;
    productId: number;
}

export interface ReviewCreateAttributes extends YLIFTCreateAttributes {
    profileId: number;
    productId: number;
    text: string;
    stars: number;
}

export interface ReviewUpdateAttributes extends YLIFTUpdateAttributes {
    profileId?: number;
    productId?: number;
    text?: string;
    stars?: number;
}


export class ReviewResource extends Resource<Review, ReviewListAttributes, ReviewCreateAttributes, ReviewUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/products/reviews', requestManager);
    }

    public list(listArgs: ReviewListAttributes): Promise<{ count: number, rows: Review[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: ReviewCreateAttributes): Promise<Review> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<Review> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: ReviewUpdateAttributes): Promise<Review> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
