import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface Role {
    name: string;
    registerKey: string;
    createdAt: Date;
    updatedAt: Date;
}

export interface RoleListAttributes extends YLIFTListAttributes {
}

export interface RoleCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    registerKey: string;
}

export interface RoleUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    registerKey?: string;
}


export class RoleResource extends Resource<Role, RoleListAttributes, RoleCreateAttributes, RoleUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/roles', requestManager);
    }

    public list(listArgs: RoleListAttributes): Promise<{ count: number, rows: Role[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: RoleCreateAttributes): Promise<Role> {
        return this._create(createArgs);
    }

    public update(id: string | number, updateArgs: RoleUpdateAttributes): Promise<Role> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
