import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';

export interface SalesAccount {
    id: string;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    email: string|null;
    phone: string|null;
    description: string|null;
    website: string|null;
    numberOfEmployees: number|null;
    estimatedRevenue: number|null;
    primaryProfileId: number|null;
    salesRepProfileId: number;
}

export interface SalesAccountListAttributes extends YLIFTListAttributes {
    name?: string;
    salesRepProfileId?: number;
    sortBy?: string;
    sortDir?: string;
}

export interface SalesAccountCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    email?: string|null;
    phone?: string|null;
    description?: string|null;
    website?: string|null;
    numberOfEmployees?: number|null;
    estimatedRevenue?: number|null;
    primaryProfileId?: number|null;
    salesRepProfileId: number;
}

export interface SalesAccountUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    email?: string|null;
    phone?: string|null;
    description?: string|null;
    website?: string|null;
    numberOfEmployees?: number|null;
    estimatedRevenue?: number|null;
    primaryProfileId?: number|null;
    salesRepProfileId?: number;
}

export class SalesAccountResource extends Resource<SalesAccount, SalesAccountListAttributes, SalesAccountCreateAttributes, SalesAccountUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/sales/accounts', requestManager);
    }

    public list(listArgs: SalesAccountListAttributes): Promise<{ count: number, rows: SalesAccount[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: SalesAccountCreateAttributes): Promise<SalesAccount> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<SalesAccount> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: SalesAccountUpdateAttributes): Promise<SalesAccount> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
    
}
