import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';
import {SalesAccount} from "./SalesAccount";

export interface SalesAccountAddress {
    id: string;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    salesAccountId: string;
    salesAccount?: SalesAccount;
    line1: string;
    line2: string|null;
    city: string;
    state: string;
    zip: string;
}

export interface SalesAccountAddressListAttributes extends YLIFTListAttributes {
    name?: string;
    salesAccountId?: string;
    state?: string;
    zip?: string;
    email?: string;
    sortBy?: string;
    sortDir?: string;
}

export interface SalesAccountAddressCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    salesAccountId: string;
    line1: string;
    line2?: string|null;
    city: string;
    state: string;
    zip: string;
}

export interface SalesAccountAddressUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    salesAccountId?: string;
    line1?: string;
    line2?: string|null;
    city?: string;
    state?: string;
    zip?: string;
}


export class SalesAccountAddressResource extends Resource<SalesAccountAddress, SalesAccountAddressListAttributes, SalesAccountAddressCreateAttributes, SalesAccountAddressUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/sales/accounts/addresses', requestManager);
    }

    public list(listArgs: SalesAccountAddressListAttributes): Promise<{ count: number, rows: SalesAccountAddress[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: SalesAccountAddressCreateAttributes): Promise<SalesAccountAddress> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<SalesAccountAddress> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: SalesAccountAddressUpdateAttributes): Promise<SalesAccountAddress> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
