import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';

export interface SalesAccountContact {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string|null;
    email: string;
    phone: string|null;
    timezone: string;
    salesAccountId: string;
}

export interface SalesAccountContactListAttributes extends YLIFTListAttributes {
    email?: string;
    name?: string;
    role?: string;
    customerId?: number;
}

export interface SalesAccountContactCreateAttributes extends YLIFTCreateAttributes {
    name?: string|null;
    email: string;
    phone?: string|null;
    timezone?: string;
    salesAccountId: string;
}

export interface SalesAccountContactUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string|null;
    email?: string;
    phone?: string|null;
    timezone?: string;
    salesAccountId?: string;
}

export class SalesAccountContactResource extends Resource<SalesAccountContact, SalesAccountContactListAttributes, SalesAccountContactCreateAttributes, SalesAccountContactUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/sales/accounts/contacts', requestManager);
    }

    public list(listArgs: SalesAccountContactListAttributes): Promise<{ count: number, rows: SalesAccountContact[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: SalesAccountContactCreateAttributes): Promise<SalesAccountContact> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<SalesAccountContact> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: SalesAccountContactUpdateAttributes): Promise<SalesAccountContact> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }

}
