import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';
import {Sku} from "./Sku";
import {ProductAttribute} from "./ProductAttribute";

export interface SkuProductAttributeDescription {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    skuId: number;
    sku?: Sku;
    description: string;
    productAttributeId: number|null;
    productAttribute?: ProductAttribute;
}

export interface SkuProductAttributeDescriptionListAttributes extends YLIFTListAttributes {
    skuId?: number;
    productId?: number;
    productAttributeId?: number;
}

export interface SkuProductAttributeDescriptionCreateAttributes extends YLIFTCreateAttributes {
    skuId: number;
    description: string;
    productAttributeId?: number|null;
}

export interface SkuProductAttributeDescriptionUpdateAttributes extends YLIFTUpdateAttributes {
    skuId?: number;
    description?: string;
    productAttributeId?: number|null;
}


export class SkuProductAttributeDescriptionResource extends Resource<SkuProductAttributeDescription, SkuProductAttributeDescriptionListAttributes, SkuProductAttributeDescriptionCreateAttributes, SkuProductAttributeDescriptionUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/products/skus/attribute-descriptions', requestManager);
    }

    public list(listArgs: SkuProductAttributeDescriptionListAttributes): Promise<{ count: number, rows: SkuProductAttributeDescription[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: SkuProductAttributeDescriptionCreateAttributes): Promise<SkuProductAttributeDescription> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<SkuProductAttributeDescription> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: SkuProductAttributeDescriptionUpdateAttributes): Promise<SkuProductAttributeDescription> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
