import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';
import {TaxableProductCategory} from "./TaxableProductCategory";
import {TaxExemptionRule} from "./TaxExemptionRule";

export interface StateTaxableProductCategoryExemptionRule {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    state: string;
    taxExemptionRuleId: number;
    taxExemptionRule?: TaxExemptionRule;
    taxableProductCategoryId: number;
    taxableProductCategory?: TaxableProductCategory;
}

export interface StateTaxableProductCategoryExemptionRuleListAttributes extends YLIFTListAttributes {
    state?: string;
    taxExemptionRuleId?: number;
    taxableProductCategoryId?: number;
}

export interface StateTaxableProductCategoryExemptionRuleCreateAttributes extends YLIFTCreateAttributes {
    state: string;
    taxExemptionRuleId: number;
    taxableProductCategoryId: number;
}

export interface StateTaxableProductCategoryExemptionRuleUpdateAttributes extends YLIFTUpdateAttributes {
    state?: string;
    taxExemptionRuleId?: number;
    taxableProductCategoryId?: number;
}


export class StateTaxableProductCategoryExemptionRuleResource extends Resource<StateTaxableProductCategoryExemptionRule, StateTaxableProductCategoryExemptionRuleListAttributes, StateTaxableProductCategoryExemptionRuleCreateAttributes, StateTaxableProductCategoryExemptionRuleUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/tax-product-categories/exemption-rules', requestManager);
    }

    public list(listArgs: StateTaxableProductCategoryExemptionRuleListAttributes): Promise<{ count: number, rows: StateTaxableProductCategoryExemptionRule[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: StateTaxableProductCategoryExemptionRuleCreateAttributes): Promise<StateTaxableProductCategoryExemptionRule> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<StateTaxableProductCategoryExemptionRule> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: StateTaxableProductCategoryExemptionRuleUpdateAttributes): Promise<StateTaxableProductCategoryExemptionRule> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
