import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface TaxExemptionRule {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    taxExemptionStatus: 'EX'|'T'|'EXS'|'TS'|'RR'|null;
    assignedTaxRate: number|null;
}

export interface TaxExemptionRuleListAttributes extends YLIFTListAttributes {
    taxExemptionStatus?: 'EX'|'T'|'EXS'|'TS'|'RR'|null;
}

export interface TaxExemptionRuleCreateAttributes extends YLIFTCreateAttributes {
    taxExemptionStatus?: 'EX'|'T'|'EXS'|'TS'|'RR'|null;
    assignedTaxRate?: number|null;
}

export interface TaxExemptionRuleUpdateAttributes extends YLIFTUpdateAttributes {
    taxExemptionStatus?: 'EX'|'T'|'EXS'|'TS'|'RR'|null;
    assignedTaxRate?: number|null;
}


export class TaxExemptionRuleResource extends Resource<TaxExemptionRule, TaxExemptionRuleListAttributes, TaxExemptionRuleCreateAttributes, TaxExemptionRuleUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/tax-exemption-rules', requestManager);
    }

    public list(listArgs: TaxExemptionRuleListAttributes): Promise<{ count: number, rows: TaxExemptionRule[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: TaxExemptionRuleCreateAttributes): Promise<TaxExemptionRule> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<TaxExemptionRule> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: TaxExemptionRuleUpdateAttributes): Promise<TaxExemptionRule> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
