import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface TaxableProductCategory {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string|null;
}

export interface TaxableProductCategoryListAttributes extends YLIFTListAttributes {
    name?: string|null;
}

export interface TaxableProductCategoryCreateAttributes extends YLIFTCreateAttributes {
    name?: string|null;
}

export interface TaxableProductCategoryUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string|null;
}


export class TaxableProductCategoryResource extends Resource<TaxableProductCategory, TaxableProductCategoryListAttributes, TaxableProductCategoryCreateAttributes, TaxableProductCategoryUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/tax-product-categories', requestManager);
    }

    public list(listArgs: TaxableProductCategoryListAttributes): Promise<{ count: number, rows: TaxableProductCategory[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: TaxableProductCategoryCreateAttributes): Promise<TaxableProductCategory> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<TaxableProductCategory> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: TaxableProductCategoryUpdateAttributes): Promise<TaxableProductCategory> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
