import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  YLIFTUpdateAttributes,
  Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Order } from "./Order";

export interface Training {
  id: number;
  createdAt: Date;
  updatedAt: Date;
  overview: string;
  categoryId: string;
  locationId: string;
  timezone: string;
  price: number;
  isActive: boolean;
  hasLiveStream: boolean;
  startTime: Date;
  endTime: Date;
  profileId: number;
  approvedByAdmin: string;
}

export interface TrainingListAttributes extends YLIFTListAttributes {
  categoryId?: string;
  locationId?: string;
  isActive?: boolean;
  hasLiveStream?: boolean;
  before?: Date;
  after?: Date;
  isPurchased?: boolean;
  createdByMe?: boolean;
  approvedByAdmin?: string;
  getDiscount?: boolean;
}

export interface TrainingCreateAttributes extends YLIFTCreateAttributes {
  overview?: string;
  categoryId: string;
  locationId?: string;
  timezone?: string;
  price?: number;
  isActive?: boolean;
  hasLiveStream?: boolean;
  startTime?: Date;
  endTime?: Date;
}

export interface TrainingOrderAttributes {
  cardId: string;
  trainingId: string;
  addressId: number;
}

export interface TrainingUpdateAttributes extends YLIFTUpdateAttributes {
  overview?: string;
  categoryId?: string;
  locationId?: string;
  timezone?: string;
  price?: number;
  isActive?: boolean;
  hasLiveStream?: boolean;
  startTime?: Date;
  endTime?: Date;
}


export class TrainingResource extends Resource<Training, TrainingListAttributes, TrainingCreateAttributes, TrainingUpdateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/trainings', requestManager);
  }

  public list(listArgs: TrainingListAttributes): Promise<{ count: number, rows: Training[] }> {
    return this._list(listArgs);
  }

  public create(createArgs: TrainingCreateAttributes): Promise<Training> {
    return this._create(createArgs);
  }

  public checkAccessible(id: string): Promise<{ accessible: boolean }> {
    return this.makeRequest({
      method: 'GET',
      url: `${this.basePath}/${id}/accessible`
    })
  }

  public order(orderArgs: TrainingOrderAttributes): Promise<Order> {
    return this.makeRequest({
      method: 'POST',
      data: orderArgs,
      url: `${this.basePath}/order`
    })
  }

  public get(id: string | number): Promise<Training> {
    return this._get(id);
  }

  public update(id: string | number, updateArgs: TrainingUpdateAttributes): Promise<Training> {
    return this._update(id, updateArgs);
  }

  public del(id: string | number): Promise<void> {
    return this.destroy(id);
  }

  public destroy(id: string | number): Promise<void> {
    return this._destroy(id);
  }
}
