import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  YLIFTUpdateAttributes,
  Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface TrainingAnswer {
  id: number;
  createdAt: Date;
  updatedAt: Date;
  trainingQuestionId: string;
  profileId: number;
  text: string;
}

export interface TrainingAnswerListAttributes extends YLIFTListAttributes {
  trainingQuestionId?: string;
  profileId?: number;
}

export interface TrainingAnswerCreateAttributes extends YLIFTCreateAttributes {
  trainingQuestionId: string;
  text: string;
}

export interface TrainingAnswerUpdateAttributes extends YLIFTUpdateAttributes {
  text: string;
}


export class TrainingAnswerResource extends Resource<TrainingAnswer, TrainingAnswerListAttributes, TrainingAnswerCreateAttributes, TrainingAnswerUpdateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/trainings/questions/answers', requestManager);
  }

  public list(listArgs: TrainingAnswerListAttributes): Promise<{ count: number, rows: TrainingAnswer[] }> {
    return this._list(listArgs);
  }

  public create(createArgs: TrainingAnswerCreateAttributes): Promise<TrainingAnswer> {
    return this._create(createArgs);
  }

  public get(id: string | number): Promise<TrainingAnswer> {
    return this._get(id);
  }

  public update(id: string | number, updateArgs: TrainingAnswerUpdateAttributes): Promise<TrainingAnswer> {
    return this._update(id, updateArgs);
  }

  public del(id: string | number): Promise<void> {
    return this.destroy(id);
  }

  public destroy(id: string | number): Promise<void> {
    return this._destroy(id);
  }
}
