import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface TrainingCategory {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    isActive: boolean;
}

export interface TrainingCategoryListAttributes extends YLIFTListAttributes {
}

export interface TrainingCategoryCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    isActive?: boolean;
}

export interface TrainingCategoryUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    isActive?: boolean;
}


export class TrainingCategoryResource extends Resource<TrainingCategory, TrainingCategoryListAttributes, TrainingCategoryCreateAttributes, TrainingCategoryUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/trainings/categories', requestManager);
    }

    public list(listArgs: TrainingCategoryListAttributes): Promise<{ count: number, rows: TrainingCategory[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: TrainingCategoryCreateAttributes): Promise<TrainingCategory> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<TrainingCategory> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: TrainingCategoryUpdateAttributes): Promise<TrainingCategory> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
