import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  YLIFTUpdateAttributes,
  Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface TrainingCompletion {
  id: number;
  createdAt: Date;
  updatedAt: Date;
  trainingId: string;
  profileId: number;
}

export interface TrainingCompletionListAttributes extends YLIFTListAttributes {
  trainingId?: string;
  profileId?: number;
}

export interface TrainingCompletionCreateAttributes extends YLIFTCreateAttributes {
  trainingId: string;
  profileId?: number;
}

export interface TrainingCompletionUpdateAttributes extends YLIFTUpdateAttributes {
}


export class TrainingCompletionResource extends Resource<TrainingCompletion, TrainingCompletionListAttributes, TrainingCompletionCreateAttributes, TrainingCompletionUpdateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/trainings/completions', requestManager);
  }

  public list(listArgs: TrainingCompletionListAttributes): Promise<{ count: number, rows: TrainingCompletion[] }> {
    return this._list(listArgs);
  }

  public create(createArgs: TrainingCompletionCreateAttributes): Promise<TrainingCompletion> {
    return this._create(createArgs);
  }

  public get(id: string | number): Promise<TrainingCompletion> {
    return this._get(id);
  }

  public update(id: string | number, updateArgs: TrainingCompletionUpdateAttributes): Promise<TrainingCompletion> {
    return this._update(id, updateArgs);
  }

  public del(id: string | number): Promise<void> {
    return this.destroy(id);
  }

  public destroy(id: string | number): Promise<void> {
    return this._destroy(id);
  }
}
