import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';

export interface TrainingDiscount {
  id: number;
  trainingId: string;
  amount: number;
  dateFrom: Date;
  dateTo: Date;
}

export interface TrainingDiscountListAttributes extends YLIFTListAttributes {
  trainingId?: string;
  showInactive?: boolean;
}

export interface TrainingDiscountCreateAttributes extends YLIFTCreateAttributes {
  trainingsId: string[];
  amount?: number | null;
  dateFrom: Date;
  dateTo: Date;
}

export class TrainingDiscountsResource extends Resource<
  TrainingDiscount,
  TrainingDiscountListAttributes,
  TrainingDiscountCreateAttributes,
  TrainingDiscountCreateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/trainings/discounts', requestManager);
  }

  public list(listArgs: TrainingDiscountListAttributes): Promise<TrainingDiscount[]> {
    return this._list(listArgs);
  }

  public create(createArgs: TrainingDiscountCreateAttributes): Promise<TrainingDiscount[]> {
    return this._create(createArgs);
  }

  public update(createArgs: TrainingDiscountCreateAttributes): Promise<TrainingDiscount[]> {
    return this._create(createArgs);
  }
}
