import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  YLIFTUpdateAttributes,
  Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface TrainingLecture {
  id: number;
  createdAt: Date;
  updatedAt: Date;
  trainingId: string;
  title: string;
  description: string;
  thumbnailUrl: string;
  contentUrl: string;
  contentType: string;
  isActive: boolean;
  isFree: boolean;
  trainingModuleId: string;
}

export interface TrainingLectureListAttributes extends YLIFTListAttributes {
  trainingId?: string;
}

export interface TrainingLectureViewListAttributes extends YLIFTListAttributes {
  trainingLectureId?: string;
  profileId?: string;
  trainingModuleId?: string;
}

export interface TrainingLectureCreateAttributes extends YLIFTCreateAttributes {
  trainingId: string;
  title?: string;
  description?: string;
  thumbnailUrl?: string;
  contentUrl?: string;
  contentType?: string;
  isActive?: boolean;
  isFree?: boolean;
  trainingModuleId?: string;
}

export interface TrainingLectureUpdateAttributes extends YLIFTUpdateAttributes {
  trainingId?: string;
  title?: string;
  description?: string;
  thumbnailUrl?: string;
  contentUrl?: string;
  contentType?: string;
  isActive?: boolean;
  isFree?: boolean;
  trainingModuleId?: string;
}


export class TrainingLectureResource extends Resource<TrainingLecture, TrainingLectureListAttributes, TrainingLectureCreateAttributes, TrainingLectureUpdateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/trainings/lectures', requestManager);
  }

  public list(listArgs: TrainingLectureListAttributes): Promise<{ count: number, rows: TrainingLecture[] }> {
    return this._list(listArgs);
  }

  public create(createArgs: TrainingLectureCreateAttributes): Promise<TrainingLecture> {
    return this._create(createArgs);
  }

  public get(id: string | number): Promise<TrainingLecture> {
    return this._get(id);
  }

  public update(id: string | number, updateArgs: TrainingLectureUpdateAttributes): Promise<TrainingLecture> {
    return this._update(id, updateArgs);
  }

  public del(id: string | number): Promise<void> {
    return this.destroy(id);
  }

  public destroy(id: string | number): Promise<void> {
    return this._destroy(id);
  }

  public trackView(id: string): Promise<void> {
    return this.makeRequest({
      method: 'POST',
      data: { trainingLectureId: id },
      url: `${this.basePath}/views`
    })
  }

  public getViews(listArgs: TrainingLectureViewListAttributes): Promise<void> {
    return this.makeRequest({
      method: 'GET',
      params: listArgs,
      url: `${this.basePath}/views`
    })
  }
}
