import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface TrainingLocation {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string;
    isActive: boolean;
}

export interface TrainingLocationListAttributes extends YLIFTListAttributes {
}

export interface TrainingLocationCreateAttributes extends YLIFTCreateAttributes {
    name: string;
    isActive?: boolean;
}

export interface TrainingLocationUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string;
    isActive?: boolean;
}


export class TrainingLocationResource extends Resource<TrainingLocation, TrainingLocationListAttributes, TrainingLocationCreateAttributes, TrainingLocationUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/trainings/locations', requestManager);
    }

    public list(listArgs: TrainingLocationListAttributes): Promise<{ count: number, rows: TrainingLocation[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: TrainingLocationCreateAttributes): Promise<TrainingLocation> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<TrainingLocation> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: TrainingLocationUpdateAttributes): Promise<TrainingLocation> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
