import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  YLIFTUpdateAttributes,
  Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface TrainingMaterial {
  id: number;
  createdAt: Date;
  updatedAt: Date;
  trainingId: string;
  title: string;
  contentUrl: string;
  contentType: string;
  size: number;
  trainingModuleId: string;
}

export interface TrainingMaterialListAttributes extends YLIFTListAttributes {
  trainingId?: string;
  trainingModuleId?: string;
}

export interface TrainingMaterialCreateAttributes extends YLIFTCreateAttributes {
  trainingId: string;
  title?: string;
  contentUrl: string;
  contentType: string;
  size?: number;
  trainingModuleId?: string;
}

export interface TrainingMaterialUpdateAttributes extends YLIFTUpdateAttributes {
  trainingId?: string;
  title?: string;
  contentUrl?: string;
  contentType?: string;
  size?: number;
  trainingModuleId?: string;
}


export class TrainingMaterialResource extends Resource<TrainingMaterial, TrainingMaterialListAttributes, TrainingMaterialCreateAttributes, TrainingMaterialUpdateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/trainings/materials', requestManager);
  }

  public list(listArgs: TrainingMaterialListAttributes): Promise<{ count: number, rows: TrainingMaterial[] }> {
    return this._list(listArgs);
  }

  public create(createArgs: TrainingMaterialCreateAttributes): Promise<TrainingMaterial> {
    return this._create(createArgs);
  }

  public get(id: string | number): Promise<TrainingMaterial> {
    return this._get(id);
  }

  public update(id: string | number, updateArgs: TrainingMaterialUpdateAttributes): Promise<TrainingMaterial> {
    return this._update(id, updateArgs);
  }

  public del(id: string | number): Promise<void> {
    return this.destroy(id);
  }

  public destroy(id: string | number): Promise<void> {
    return this._destroy(id);
  }

}
