import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  YLIFTUpdateAttributes,
  Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface TrainingModule {
  id: string;
  trainingId?: string;
  title?: string;
  order?: number;
}

export interface TrainingModuleListAttributes extends YLIFTListAttributes {
  trainingId?: string;
}

export interface TrainingModuleCreateAttributes extends YLIFTCreateAttributes {
  trainingId: string;
  title: string;
  order: number;
}

export interface TrainingModuleUpdateAttributes extends YLIFTUpdateAttributes {
  title?: string;
  order?: number;
}

export interface TrainingModuleReorderAttributes {
  trainingId: string;
  trainingModules: TrainingModule[];
}


export class TrainingModuleResource extends Resource<TrainingModule, TrainingModuleListAttributes, TrainingModuleCreateAttributes, TrainingModuleUpdateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/trainings/modules', requestManager);
  }

  public list(listArgs: TrainingModuleListAttributes): Promise<TrainingModule[]> {
    return this._list(listArgs);
  }

  public create(createArgs: TrainingModuleCreateAttributes): Promise<TrainingModule> {
    return this._create(createArgs);
  }

  public get(id: string): Promise<TrainingModule> {
    return this._get(id);
  }

  public update(id: string, updateArgs: TrainingModuleUpdateAttributes): Promise<TrainingModule> {
    return this._update(id, updateArgs);
  }

  public reorder(reorderArgs: TrainingModuleReorderAttributes): Promise<TrainingModule[]> {
    return this.makeRequest({
      method: 'POST',
      url: `${this.basePath}/${reorderArgs.trainingId}`,
      data: {
        trainingModules: reorderArgs.trainingModules
      }
    });
  }

  public del(id: string): Promise<void> {
    return this.destroy(id);
  }

  public destroy(id: string): Promise<void> {
    return this._destroy(id);
  }

}
