import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  YLIFTUpdateAttributes,
  Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface TrainingQuestion {
  id: number;
  createdAt: Date;
  updatedAt: Date;
  trainingId: string;
  profileId: number;
  text: string;
}

export interface TrainingQuestionListAttributes extends YLIFTListAttributes {
  trainingId?: string;
  profileId?: number;
}

export interface TrainingQuestionCreateAttributes extends YLIFTCreateAttributes {
  trainingId: string;
  text: string;
}

export interface TrainingQuestionUpdateAttributes extends YLIFTUpdateAttributes {
  text: string;
}


export class TrainingQuestionResource extends Resource<TrainingQuestion, TrainingQuestionListAttributes, TrainingQuestionCreateAttributes, TrainingQuestionUpdateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/trainings/questions', requestManager);
  }

  public list(listArgs: TrainingQuestionListAttributes): Promise<{ count: number, rows: TrainingQuestion[] }> {
    return this._list(listArgs);
  }

  public create(createArgs: TrainingQuestionCreateAttributes): Promise<TrainingQuestion> {
    return this._create(createArgs);
  }

  public get(id: string | number): Promise<TrainingQuestion> {
    return this._get(id);
  }

  public update(id: string | number, updateArgs: TrainingQuestionUpdateAttributes): Promise<TrainingQuestion> {
    return this._update(id, updateArgs);
  }

  public del(id: string | number): Promise<void> {
    return this.destroy(id);
  }

  public destroy(id: string | number): Promise<void> {
    return this._destroy(id);
  }
}
