import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  YLIFTUpdateAttributes,
  Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';

export interface TrainingQuiz {
  id: number;
  trainingId: string;
  title: string;
  questions: string;
  trainingModuleId: string;
}

export interface TrainingQuizListAttributes extends YLIFTListAttributes {
  trainingId?: string;
  trainingModuleId?: string;
}

export interface TrainingQuizCompleteListAttributes extends YLIFTListAttributes {
  trainingQuizId?: string;
  profileId?: string;
  trainingModuleId?: string;
}

export interface TrainingQuizCreateAttributes extends YLIFTCreateAttributes {
  trainingId: string;
  title?: string;
  questions?: string;
  trainingModuleId?: string;
}

export interface TrainingQuizUpdateAttributes extends YLIFTUpdateAttributes {
  trainingId?: string;
  title?: string;
  questions?: string;
  trainingModuleId?: string;
}


export class TrainingQuizResource extends Resource<TrainingQuiz, TrainingQuizListAttributes, TrainingQuizCreateAttributes, TrainingQuizUpdateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/trainings/quizzes', requestManager);
  }

  public list(listArgs: TrainingQuizListAttributes): Promise<{ count: number, rows: TrainingQuiz[] }> {
    return this._list(listArgs);
  }

  public create(createArgs: TrainingQuizCreateAttributes): Promise<TrainingQuiz> {
    return this._create(createArgs);
  }

  public get(id: string | number): Promise<TrainingQuiz> {
    return this._get(id);
  }

  public update(id: string | number, updateArgs: TrainingQuizUpdateAttributes): Promise<TrainingQuiz> {
    return this._update(id, updateArgs);
  }

  public del(id: string | number): Promise<void> {
    return this.destroy(id);
  }

  public destroy(id: string | number): Promise<void> {
    return this._destroy(id);
  }

  public trackCompletion(id: string): Promise<void> {
    return this.makeRequest({
      method: 'POST',
      data: { trainingQuizId: id },
      url: `${this.basePath}/completions`
    })
  }

  public getCompletions(listArgs: TrainingQuizCompleteListAttributes): Promise<void> {
    return this.makeRequest({
      method: 'GET',
      params: listArgs,
      url: `${this.basePath}/completions`
    })
  }
}
