import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';
import { Profile } from './Profile';

export interface RatedTraining {
  id: number;
  createdAt: Date;
  updatedAt: Date;
  overview: string;
  categoryId: string;
  locationId: string;
  timezone: string;
  price: number;
  isActive: boolean;
  hasLiveStream: boolean;
  startTime: Date;
  endTime: Date;
  rate: number;
}

export interface RateRecord {
  comment: string;
  id: number;
  profileId: number;
  rate: number;
  trainingId: string;
  updatedAt: Date;
  createdAt: Date;
  profile: Profile;
}

export interface ReviewMark {
  rate: number;
  count: number;
}

export interface TrainingRatingsListAttributes extends YLIFTListAttributes {
  trainingId: string;
}

export interface TrainingRatingCreateAttributes extends YLIFTCreateAttributes {
  trainingId: string;
  rate: number;
  comment?: string;
}

export interface TrainingRatingDeleteAttributes {
  trainingId: string;
}

export interface TrainingRatingMyAttributes extends YLIFTListAttributes {
  trainingId: string;
}

export interface TrainingRatingMarksAttributes extends YLIFTListAttributes {
  trainingId: string;
}

export interface TrainingRatingRatedAttributes extends YLIFTListAttributes {
  categoryId: string;
  limit?: number;
  offset?: number;
}


export class TrainingRatingsResource extends Resource<RateRecord, TrainingRatingsListAttributes, TrainingRatingCreateAttributes, TrainingRatingCreateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/trainings/ratings', requestManager);
  }

  public list(listArgs: TrainingRatingsListAttributes): Promise<RateRecord[]> {
    return this._list(listArgs);
  }

  public create(createArgs: TrainingRatingCreateAttributes): Promise<{success: boolean}> {
    return this._create(createArgs);
  }

  public update(createArgs: TrainingRatingCreateAttributes): Promise<{success: boolean}> {
    return this._create(createArgs);
  }

  public my(listArgs: TrainingRatingMyAttributes): Promise<RateRecord> {
    return this.makeRequest({
      method: 'GET',
      url: `${this.basePath}/my?trainingId=${listArgs.trainingId}`
    });
  }

  public marks(markArgs: TrainingRatingMarksAttributes): Promise<ReviewMark[]> {
    return this.makeRequest({
      method: 'GET',
      url: `${this.basePath}/marks?trainingId=${markArgs.trainingId}`
    });
  }

  public del(delArgs: TrainingRatingDeleteAttributes): Promise<{success: boolean}> {
    return this.makeRequest({
      method: 'DELETE',
      url: `${this.basePath}?trainingId=${delArgs.trainingId}`
    });
  }

  public rated(ratedArgs: TrainingRatingRatedAttributes): Promise<RatedTraining[]> {
    let url = `${this.basePath}/rated?categoryId=${ratedArgs.categoryId}`;
    if (ratedArgs.limit) {
      url += `&limit=${ratedArgs.limit}`;
    }
    if (ratedArgs.offset) {
      url += `&offset=${ratedArgs.offset}`;
    }

    return this.makeRequest({
      method: 'GET',
      url
    });
  }
}
