import * as Promise from 'bluebird';

import {
  YLIFTListAttributes,
  Resource
} from '../utils/Resource';
import { RequestManager } from '../RequestManager';

export interface TrainingStatisticsRow {
  id: string;
  title: string;
  finished: number;
  inProgress: number;
  purchasedCount: number;
  totalLectures: number;
  totalViews: number;
}

export interface TrainingFinancesRow {
  amount: number;
  buyerName: string;
  buyerProfileId: number;
  discount: number;
  id: number;
  ownerName: string;
  ownerProfileId: number;
  title: string;
  trainingId: string;
  transactionDate: Date;
  systemCommissionPercent?: number;
  systemCommission?: number;
}

export interface TrainingStatistics {
  count: number,
  rows: TrainingStatisticsRow[],
}

export interface TrainingFinances {
  count: number;
  rows: TrainingFinancesRow[],
  totalAmount: number;
}

export interface TrainingStatisticsListAttributes extends YLIFTListAttributes {
  limit?: number;
  offset?: number;
  dateFrom?: Date;
  dateTo?: Date;
}

export interface TrainingFinancesListAttributes extends YLIFTListAttributes {
  limit?: number;
  offset?: number;
  dateFrom?: Date;
  dateTo?: Date;
}

export class TrainingStatisticsResource extends Resource<TrainingStatistics, TrainingStatisticsListAttributes, any, any> {
  constructor(requestManager: RequestManager) {
    super('/trainings/statistics', requestManager);
  }

  public list(listArgs: TrainingStatisticsListAttributes): Promise<TrainingStatistics> {
    return this._list(listArgs);
  }

  public finances(listArgs: TrainingFinancesListAttributes): Promise<TrainingFinances> {
    let queryStr = '';
    Object.keys(listArgs).forEach((key, index) => {
      if (!index) {
        queryStr += '?';
      }
      queryStr += `${key}=${listArgs[key]}&`;
    });
    queryStr = queryStr.substr(0, queryStr.length - 1);

    return this.makeRequest({
      method: 'GET',
      url: `${this.basePath}/finances${queryStr}`
    });
  }
}
