import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';
import {SkuRoleAttribute} from './Sku';
import {ProductRoleAttributeUpdateAttributes} from './Product';

export interface Vendor {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string|null;
    position: number|null;
    orderWindowStartTime: string|null;
    orderWindowEndTime: string|null;
    isPreferred: boolean;
}

export interface VendorListAttributes extends YLIFTListAttributes {
    name?: string|null;
}

export interface VendorCreateAttributes extends YLIFTCreateAttributes {
    name?: string|null;
    position?: number|null;
    orderWindowStartTime?: string|null;
    orderWindowEndTime?: string|null;
    isPreferred?: boolean;
}

export interface VendorUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string|null;
    position?: number|null;
    orderWindowStartTime?: string|null;
    orderWindowEndTime?: string|null;
    isPreferred?: boolean;
}

export interface VendorEmailSettings {
    id: number;
    displayUnitPrice: boolean;
    displayVendorCost: boolean;
    displayTaxAmount: boolean;
    displayShippingAmount: boolean;
    displayMedicalLicense: boolean;
    vendorId: number;
    createdAt: Date;
    updatedAt: Date;
}

export interface VendorEmailSettingsUpdateAttributes extends YLIFTUpdateAttributes {
    displayUnitPrice?: boolean;
    displayVendorCost?: boolean;
    displayTaxAmount?: boolean;
    displayShippingAmount?: boolean;
    displayMedicalLicense?: boolean;
}

export class VendorResource extends Resource<Vendor, VendorListAttributes, VendorCreateAttributes, VendorUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/vendors', requestManager);
    }

    public list(listArgs: VendorListAttributes): Promise<{ count: number, rows: Vendor[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: VendorCreateAttributes): Promise<Vendor> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<Vendor> {
        return this._get(id);
    }

    public getEmailSettings(vendorId: number): Promise<VendorEmailSettings> {
        return this.makeRequest({
            method: 'GET',
            params: {vendorId},
            url: `${this.basePath}/email-settings`
        })
    }

    public update(id: string | number, updateArgs: VendorUpdateAttributes): Promise<Vendor> {
        return this._update(id, updateArgs);
    }

    public updateEmailSettings(updateArgs: VendorEmailSettingsUpdateAttributes): Promise<VendorEmailSettings> {
        return this.makeRequest({
            method: 'PUT',
            data: updateArgs,
            url: `${this.basePath}/email-settings`
        })
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
