import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';
import {Vendor} from "./Vendor";

export interface VendorAddress {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string|null;
    vendorId: number;
    vendor?: Vendor;
    line1: string;
    line2: string|null;
    city: string;
    state: string;
    zip: string;
    phone: string|null;
    email: string;
    shippoObjectId: string|null;
}

export interface VendorAddressListAttributes extends YLIFTListAttributes {
    name?: string|null;
    vendorId?: number|null;
    state?: string|null;
    zip?: string|null;
    email?: string|null;
}

export interface VendorAddressCreateAttributes extends YLIFTCreateAttributes {
    name?: string|null;
    vendorId: number;
    line1: string;
    line2?: string|null;
    city: string;
    state: string;
    zip: string;
    phone?: string|null;
    email: string;
    shippoObjectId?: string|null;
}

export interface VendorAddressUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string|null;
    vendorId?: number;
    line1?: string;
    line2?: string|null;
    city?: string;
    state?: string;
    zip?: string;
    phone?: string|null;
    email?: string;
    shippoObjectId?: string|null;
}


export class VendorAddressResource extends Resource<VendorAddress, VendorAddressListAttributes, VendorAddressCreateAttributes, VendorAddressUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/vendors/addresses', requestManager);
    }

    public list(listArgs: VendorAddressListAttributes): Promise<{ count: number, rows: VendorAddress[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: VendorAddressCreateAttributes): Promise<VendorAddress> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<VendorAddress> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: VendorAddressUpdateAttributes): Promise<VendorAddress> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
