import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';
import {Vendor} from "./Vendor";

export interface VendorContact {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    name: string|null;
    vendorId: number;
    vendor?: Vendor;
    phone: string|null;
    email: string|null;
    isMaster: boolean|null;
}

export interface VendorContactListAttributes extends YLIFTListAttributes {
    name?: string|null;
    vendorId?: number;
    phone?: string|null;
    email?: string|null;
    isMaster?: boolean|null;
}

export interface VendorContactCreateAttributes extends YLIFTCreateAttributes {
    name?: string|null;
    vendorId: number;
    phone?: string|null;
    email?: string|null;
    isMaster?: boolean|null;
}

export interface VendorContactUpdateAttributes extends YLIFTUpdateAttributes {
    name?: string|null;
    vendorId?: number;
    phone?: string|null;
    email?: string|null;
    isMaster?: boolean|null;
}


export class VendorContactResource extends Resource<VendorContact, VendorContactListAttributes, VendorContactCreateAttributes, VendorContactUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/vendors/contacts', requestManager);
    }

    public list(listArgs: VendorContactListAttributes): Promise<{ count: number, rows: VendorContact[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: VendorContactCreateAttributes): Promise<VendorContact> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<VendorContact> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: VendorContactUpdateAttributes): Promise<VendorContact> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
