import * as Promise from 'bluebird';

import {
  YLIFTCreateAttributes,
  YLIFTListAttributes,
  YLIFTUpdateAttributes,
  Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';
import {Vendor} from "./Vendor";

export interface VendorOrderRule {
  id: number;
  createdAt: Date;
  updatedAt: Date;
  minOrderAmount: number;
  vendorId: number;
  vendor?: Vendor;
}

export interface VendorOrderRuleListAttributes extends YLIFTListAttributes {
  vendorId?: number;
}

export interface VendorOrderRuleCreateAttributes extends YLIFTCreateAttributes {
  name?: string|null;
  vendorId: number;
  phone?: string|null;
  email?: string|null;
  isMaster?: boolean|null;
}

export interface VendorOrderRuleUpdateAttributes extends YLIFTUpdateAttributes {
  vendorId: number;
  minOrderAmount?: number;
}


export class VendorOrderRuleResource extends Resource<VendorOrderRule, VendorOrderRuleListAttributes, VendorOrderRuleCreateAttributes, VendorOrderRuleUpdateAttributes> {
  constructor(requestManager: RequestManager) {
    super('/vendors/order-rules', requestManager);
  }

  public list(listArgs: VendorOrderRuleListAttributes): Promise<{ count: number, rows: VendorOrderRule[] }> {
    return this._list(listArgs);
  }

  public create(createArgs: VendorOrderRuleCreateAttributes): Promise<VendorOrderRule> {
    return this._create(createArgs);
  }

  public get(id: string | number): Promise<VendorOrderRule> {
    return this._get(id);
  }

  public update(id: string | number, updateArgs: VendorOrderRuleUpdateAttributes): Promise<VendorOrderRule> {
    return this._update(id, updateArgs);
  }

  public del(id: string | number): Promise<void> {
    return this.destroy(id);
  }

  public destroy(id: string | number): Promise<void> {
    return this._destroy(id);
  }
}
