import * as Promise from 'bluebird';

import {
    YLIFTCreateAttributes,
    YLIFTListAttributes,
    YLIFTUpdateAttributes,
    Resource
} from '../utils/Resource';
import {RequestManager} from '../RequestManager';
import {Vendor} from "./Vendor";

export interface VendorShippingSetting {
    vendorId: number;
    vendor?: Vendor;
    createdAt: Date;
    updatedAt: Date;
    flatRate: boolean;
    groupSize: number|null;
    expressRate: number|null;
    overnightRate: number|null;
    regularRate: number|null;
}

export interface VendorShippingSettingListAttributes extends YLIFTListAttributes {
    vendorId?: number;
}

export interface VendorShippingSettingCreateAttributes extends YLIFTCreateAttributes {
    vendorId: number;
    flatRate?: boolean;
    groupSize?: number|null;
    expressRate?: number|null;
    overnightRate?: number|null;
    regularRate?: number|null;
}

export interface VendorShippingSettingUpdateAttributes {
    vendorId: number;
    flatRate?: boolean;
    groupSize?: number|null;
    expressRate?: number|null;
    overnightRate?: number|null;
    regularRate?: number|null;
}


export class VendorShippingSettingResource extends Resource<VendorShippingSetting, VendorShippingSettingListAttributes, VendorShippingSettingCreateAttributes, VendorShippingSettingUpdateAttributes> {
    constructor(requestManager: RequestManager) {
        super('/vendors/shipping-settings', requestManager);
    }

    public list(listArgs: VendorShippingSettingListAttributes): Promise<{ count: number, rows: VendorShippingSetting[] }> {
        return this._list(listArgs);
    }

    public create(createArgs: VendorShippingSettingCreateAttributes): Promise<VendorShippingSetting> {
        return this._create(createArgs);
    }

    public get(id: string | number): Promise<VendorShippingSetting> {
        return this._get(id);
    }

    public update(id: string | number, updateArgs: VendorShippingSettingUpdateAttributes): Promise<VendorShippingSetting> {
        return this._update(id, updateArgs);
    }

    public del(id: string | number): Promise<void> {
        return this.destroy(id);
    }

    public destroy(id: string | number): Promise<void> {
        return this._destroy(id);
    }
}
