import { defaultsDeep } from 'lodash';
import * as joi from 'joi';

import { ClientError } from './ClientError';
import { ClientConfiguration } from '../Client';
import { defaultAxiosConfig } from '../RequestManager';

export const Schema = {
    clientId: joi.string().required(),
    clientSecret: joi.string(),
    redirectUri: joi.string().uri(),
    baseApiUrl: joi.string().uri(),
    baseAuthUrl: joi.string().uri(),
    request: joi.object()
};

export function Factory (config: ClientConfiguration): ClientConfiguration {
    const validation = joi.validate(config, Schema);
    if (validation.error) throw new ClientError(validation.error.annotate());
    return defaultsDeep(config, {
        baseApiUrl: 'https://api.ylift.com/v1',
        baseAuthUrl: 'https://accounts.ylift.com',
        request: defaultAxiosConfig
    });
}
